# Einleitung 

Die Vielzahl verbauter Sensoren in Smartphones macht deren Einsatzmöglichkeiten immer umfangreicher. Durch den Zugriff von Software auf die Sensoren werden nützliche Features umgesetzt: So dient das Smartphone beispielsweise durch den Einsatz des Lagesensors als Wasserwaage oder wird mithilfe des Beschleunigungssensors zu einem Schrittzähler. Ein besonderes Interesse erhält hierbei die Standortbestimmung der Geräte. Sie ermöglicht Anwendungen zur Navigation oder das Steuern von ortsgebundenen Aktionen. Die meisten dieser Anwendungen kommen mit einem Auflösungsvermögen von wenigen Metern zurecht, da oft eine größere Entfernung zwischen den Orten besteht [@Bajaj_2002a]. Bei der Distanzmessung wird die Strecke, die ein Gerät in Bewegung zurücklegt, erfasst. Findet diese Bewegung in einem engen Rahmen, wie beispielsweise einem Tisch statt, so ist diese Auflösung nicht mehr ausreichend.

Viele der Sensoren im Smartphone können alleine oder in Kombination zur Lokalisierung eingesetzt werden. Hierbei unterscheiden sich die Lösungen in der Genauigkeit sowie ihrem Einsatzgebiet und dem finanziellen Aufwand der Umsetzung. Beispielsweise ist das \ac{gps} weniger gut geeignet für die Lokalisierung in Innenräumen [@Bajaj_2002a]. Auch der finanzielle und zeitliche Aufwand der Lösungsansätze unterscheidet sich. In dieser Arbeit soll daher untersucht werden, wie die Messung auf kleinen Skalen im Zentimeterbereich mit einfachen Mitteln umgesetzt werden kann.

## Problemstellung und Motivation

Die Open-Source-Andwendung phyphox&reg; [@phyphox] ermöglicht es mithilfe der im Smartphone verbauten Sensoren Experimente durchzuführen. Wie aus einem Interview mit dem Entwickler [@MI191_2021, ab: 1 h 30 min] hervor geht, wird die Applikation unter anderem in der Lehre eingesetzt, um physikalische oder chemische Zusammenhänge für die Schüler erlebbar zu machen. Sie ersetzt dabei teils kostenintensive Lehrmaterialien, die nicht an jeder Schule verfügbar sind. Dadurch hilft phyphox&reg; bei der Verbesserung und Verbreitung von physikalischer und chemischer Bildung. 

Zur Durchführung der Experimente liest die Anwendung die Sensordaten des Smartphones aus und zeichnet diese auf. Durch die Kombination verschiedener Sensoren und Parameter (beispielsweise die Zeit), lassen sich so verschiedenste Experimente realisieren [@Staacks_2018]. Ein Beispiel für ein solches Experiment ist die Ermittlung der Länge eines Pendels. Hierbei wird das Smartphone an das Pendel gehängt und unter Einsatz des Beschleunigungssensors die Richtungsänderung erkannt und somit die Pendelfrequenz ermittelt. Aus der Pendelfrequenz lässt sich dann die Länge des Pendels errechnen.

Aktuell fehlt es der Anwendung an einer Möglichkeit, das Smartphone im Raum zu lokalisieren. Durch die Lokalisierung kann eine Distanzmessung durchgeführt oder der zurückgelegte Weg aufgezeichnet werden. Die Implementierung einer Lokalisierungslösung würde den Umfang an möglichen Experimenten somit erweitern. Beispiele für solche Experimente sind:

- **Darstellung Abstandsgesetz:** Das Abstandsgesetz beschreibt den Abfall der Energie von allem, was sich kugelförmig ausbreitet: Als Beispiel sei hier der Schall oder das Licht genannt. Die Oberfläche einer Kugel wächst mit zunehmendem Abstand, dem Radius $r$, zum Quadrat. Die Energie nimmt somit im Quadrat zum Abstand der Quelle ab [@Harten_2012_BOOK, S. 123]. Dieses Gesetz lässt sich mit dem Smartphone in einem Experiment veranschaulichen. Hierbei kann man den Schalldruck mit dem Mikrofon oder die Lichtintensität mit dem Helligkeitssensor messen und zusammen mit der Entfernungsänderung aufzeichnen.
- **Foucault'sche Pendel:** Bei einem Foucault'schen Pendel kann man über den Tagesverlauf beobachten, dass sich die Schwingungsebene des Pendels über den Tag dreht. Hier könnte eine möglichst genaue Aufzeichnung der Schwingungsebene die Rotation über den Versuchszeitraum aufzeichnen [@Lichtenegger_2015a, S. 25 Rotierende Systeme]. 

Damit diese Erweiterung möglichst vielen Nutzern der Anwendung zugänglich ist, beschränkt sich die Auswahl der Sensoren auf solche, die in möglichst vielen Smartphones verbaut sind oder durch den Einsatz von Bluetooth, welches in allen gängigen Smartphones zu finden ist. Aus diesem Grund soll dies näher betrachtet werden. In der Forschung ist das Interesse an Bluetooth, im Bereich der Innenraumnavigation, groß. Aus der Literaturrecherche geht hervor, dass die Abweichung von Bluetooth bei der Lokalisierung meist mehrere Meter groß ist [@Cho_2015a; @Paterna_2017]. Diese hohe Abweichung ist für die angesprochenen Experimente nicht geeignet. In dieser Arbeit soll untersucht werden, ob die Abweichung durch den Einsatz verschiedener Techniken auf wenige Zentimeter reduziert werden kann, um sie für Experimente nutzbar zu machen.

## Zielsetzung

Das Ziel dieser Arbeit liegt in der Entwicklung eines Lösungsansatzes, der die Umsetzung einer Lokalisierung zur Durchführung von Experimenten mittels Smartphone ermöglicht. Die Lösung soll dabei kostengünstig und möglichst einfach umsetzbar sein, damit sie für Schulen einsetzbar ist.

Cho et al. beschreiben in ihrer Arbeit [@Cho_2015a] eine Methode zur Verbesserung der Entfernungsmessung mithilfe von Bluetooth-Beacon und einem sich selbst korrigierendem Systems. Dabei wird eine Abweichung von unter \SI{10}{\percent} auf einer Distanz von bis zu \siacl{1.5}{m}{\meter} erreicht. Es soll untersucht werden, ob dieses System auch zur Positionsbestimmung eingesetzt und dadurch die Abweichung reduziert werden kann. Der zusätzliche Einsatz verschiedener Filtermethoden und eine Kalibrierung sollen auf ihren Einfluss auf die Messergebnisse hin untersucht werden. Der Versuchsaufbau soll so gestaltet sein, dass er in Schulen und anderen Umgebungen leicht nachgestellt werden kann.

Der eigene Beitrag liegt darin, ein neuartiges Konzept zu erarbeiten, welches eine Distanzmessung auf der Skala eines Tischexperiments ermöglicht. Hierzu wird das System von selbst korrigierenden Beacons aus der Arbeit [@Cho_2015a] auf die zweite Dimension ausgeweitet. Entwickelt wird ein Versuchsaufbau mit selbst korrigierenden Beacons, welcher leicht nachvollziehbar ist und die Fehleranfälligkeit verringert. Durch eine an den Versuchsaufbau und das System angepasste Kalibrierung sowie den Einsatz verschiedener Filter soll die Genauigkeit weiter erhöht werden. 

Die angepasste Kalibrierung, die Filter und die Auswirkung der selbst korrigierenden Beacons werden anhand einer experimentellen Basis evaluiert. Dabei werden verschiedene Bewertungskriterien zur Fehlerbewertung herangezogen und die einzelnen Maßnahmen zueinander betrachtet. Die Evaluierung wird exemplarisch anhand eines OnePlus 7t und Bluetooth-Beacons von Puck.js durchgeführt.

## Aufbau der Arbeit

Kapitel \ref{einleitung} gibt eine Motivation und beschreibt das Themenfeld dieser Arbeit. Darüber hinaus wird die Problemstellung beschrieben, der Lösungsansatz dargelegt und eigene Beitrag herausgearbeitet. Im Kapitel \ref{grundlagen} werden die theoretischen Grundlagen und der Stand der Forschung beschrieben. Des Weiteren findet in diesem Kapitel eine Eingrenzung des Themenfelds auf bestimmte Methoden zur Lösung des Problems statt.

In Kapitel \ref{implementierung} erfolgt die Auswahl und Entwicklung der Komponenten. Es unterteilt sich in die verwendete Hardware, die zur Umsetzung nötig ist und erläutert deren Einsatzbereich. Dabei wird auf die Umsetzung der Programmierung eingegangen. Der letzten Abschnitt beschäftigt sich mit einzelnen Aspekten der Auswertung.

Im Kapitel \ref{versuchsvorbereitung} werden grundlegende Eigenschaften des Systems vor den eigentlichen Versuchen untersucht. Die durchgeführten Messreihen bieten dabei einen Einblick in das verwendete System und dienen als Grundlage für die Entwicklung des Versuchsaufbaus in Kapitel \ref{versuchsaufbau}. Dazu werden zunächst Messungen im freien, mit einem Abstand von \SI{200}{\meter} zu Wänden und möglichen elektrischen Strahlungsquellen, durchgeführt, um die Störeinflüsse zu reduzieren. Betrachtet werden verschiedene Positionierungen zwischen den eingesetzten Geräten und deren Auswirkung auf die Dämpfung. Abschließend wird eine angepasste Kalibrierung des Systems vorgenommen.

Die Erkenntnisse aus Kapitel \ref{versuchsvorbereitung} dienen als Grundlage für den Versuchsaufbau, der in Kapitel \ref{versuchsaufbau} beschrieben wird. Dabei wird die Anordnung der Geräte in der Versuchsdurchführung bestimmt. Ferner wird auf die Messpunkte des Versuchs sowie auf Besonderheiten bei der Versuchsdurchführung eingegangen.

In Kapitel \ref{ergebnisse} wird das System anhand von Experimenten bewertet. Sowohl die eingesetzten Methode, als auch die verschiedenen Filter werden gegenübergestellt. Eine abschließende Diskussion zu den Erkenntnisse aus der Voruntersuchung und den Ergebnissen des Versuchs findet sich in Kapitel \ref{diskussion}.

Eine Zusammenfassung der Arbeit findet sich in Kapitel \ref{zusammenfassung}. Hier werden die Ergebnisse nochmal in der Gesamtheit betrachtet und in Bezug auf den Stand der Technik erörtert. Abschließend wird ein Ausblick auf mögliche Verbesserungen und Erweiterungen des Lokalisierungssystems gegeben.


# Grundlagen

Im Jahr 2021 wurden unter dem \ac{ieee} 15 Journal veröffentlicht, die sich mit dem Thema Lokalisierung mittels Bluetooth beschäftigen, dies legt ein großes Interesse an diesem Forschungsgebiet nah. Die Anwendungsfälle reichen von der Aufzeichnung von Wegen über die Navigation bis hin zur Verfolgung von Objekten. Bei vielen Anwendungsbereichen ist eine Genauigkeit von wenigen Metern ausreichend. Dies ändert sich, wenn man Experimente auf kleineren Maßstäben wie zum Beispiel einem Tisch durchführen möchte. Hierbei entscheiden wenige Zentimeter Abweichung über das Gelingen des Experiments.

In diesem Kapitel werden die technischen Grundlagen erörtert. Zunächst werden die Techniken zur Lokalisierung besprochen und eine abschließende Bewertung durchgeführt. In den nachfolgenden Abschnitten werden die Grundlagen hinsichtlich dieser Bewertung vertieft.

## Distanzmessung

Die Distanzmessung beschreibt im Rahmen dieser Arbeit die Messung der Länge einer zurückgelegten Strecke. Dabei bezeichnet die Strecke den Weg zwischen Start- und Zielpunkt. Die digitale Erfassung einer Strecke basiert auf der Erfassung einzelner Wegpunkte [@Lerch_2006_BOOK, vgl. S. 7-8]. Da zwischen den Wegpunkten keine Informationen vorliegen, wird dieser Zwischenraum als Gerade angenommen. 

![Auswirkung unterschiedlicher Anzahl von erfassten Wegpunkten. \label{fig:wegpunktcount}](../static/Wegpunkte.pdf){ width=70% }

Wie Abbildung \ref{fig:wegpunktcount} verdeutlicht, wird die Streckenabbildung durch die Anzahl an aufgezeichneten Wegpunkten verbessert. Im linken Teil der Abbildung werden nur drei Messpunkte erfasst, der ermittelte Weg ergibt nahezu eine Gerade und entspricht nicht dem realen Weg. Im rechten Teil sind acht gleichmäßig verteilte Messpunkte erfasst worden, der aufgezeichnete Weg entspricht fast dem realen Weg. 

## Lokalisierung

Zur Bestimmung der einzelnen Wegpunkte ist eine Lokalisierung des Messobjektes erforderlich. Hierbei wird die Position des Objekts bestimmt. Die Positionsbestimmung kann dabei eindimensional oder mehrdimensional sein [@Strang_2008_BOOK]. Strang et al. beschreiben in ihrem Buch [@Strang_2008_BOOK] ein und mehrdimensionale Lokalisierungsverfahren, die relevantesten werden in den nachfolgenden Kapiteln näher erläutert.

### Cell-ID

Zu den einfachsten Methoden der Lokalisierung gehört das \ac{cellid}-Verfahren. Dabei haben alle Sender einen eindeutig zugeordneten \ac{id}. Diese \ac{id} wird vom Sender mit ausgestrahlt. Der Empfangsbereich, in dem ein Sender empfangen werden kann, nennt sich Zelle (engl. Cell). Ein Empfänger dieses Signals kann dieses durch die \ac{id} eindeutig einem Sender und dessen Zelle zuordnen [@Strang_2008_BOOK]. Dabei ist die Genauigkeit des Verfahrens im Wesentlichen von der Reichweite, also der Größe der jeweiligen Zelle, des Senders abhängig. 

![Positionsbestimmung durch überschneidende Zellen. \label{fig:cellid}](../static/cellid.pdf){width=80%}

 Die Lokalisierung kann verbessert werden, wenn sich mehrere Sendezellen überlappen. Abbildung \ref{fig:cellid} rechts zeigt, das in diesem Fall die Position des Empfängers auf die Schnittmenge der Sendezellen begrenzt wird, die vom Empfänger empfangen werden. Der rötlich eingefärbte Bereich kennzeichnet das Areal, in dem sich der Empfänger befinden kann. Die rote Begrenzung ist die Sendereichweite des Senders, sie ist in der Realität jedoch nicht so homogen wie dargestellt.


### Fingerprinting

Das Fingerprinting ist ein Ansatz, der sich die Mehrwegausbreitung (mehr dazu in Abschnitt \ref{messung-fehler}) von Funksignalen zu Nutze macht. Hierbei wird für jeden Empfangsort ein charakteristisches Muster (Fingerabdruck, engl. Fingerprint) aufgezeichnet [@Strang_2008_BOOK]. Dabei gliedert sich dieses Verfahren in zwei Phasen:

1. Die Offline-Phase: Hierbei werden passende ortsabhängige Parameter bestimmt, durch die eine eindeutige Identifikation eines Ortes möglich ist. Diese Parameter werden für jeden Ort gemessen und in einer Datenbank mit der Ortsinformation verknüpft gespeichert. Die starke Ortsabhängigkeit der Parameter führt dazu, dass bei Umgebungsänderungen diese aktualisiert werden müssen.
2. Die Online-Phase: Dabei misst der Empfänger den Fingerprint, also den Parameter zur Identifikation, und gleicht diesen mit der Datenbank ab. Dazu werden Mustererkennungsalgorithmen benötigt, welche aus der Datenbank den wahrscheinlichsten Fingerprint ermitteln und damit den wahrscheinlichsten Ort herausgeben.


### Triangulation

Die Triangulation basiert auf der Ermittlung des Einfallswinkels der eingehenden Signale. Dieses Verfahren wird auch \ac{aoa} genannt. Die Messung des Einfallswinkels ist mit gerichteten Antennenarrays oder Laufzeitmessungen zwischen mehreren Antennen möglich. Für den einfachen Fall einer Messung, bei der nur ein Sender und Empfer beteiligt sind, kann keine Entfernungsinformation gewonnen werden. Erst die Messungen des Einfallswinkels von zwei Sendern führt zu einem linearen Gleichungssystem, dessen Lösung die Position des Empfängers bestimmt [@Strang_2008_BOOK]. Abbildung \ref{fig:aoa} zeigt dies beispielhaft mit zwei Sender und ein Empfänger.

![2D Positionierung über \acl{aoa}. \label{fig:aoa}](../static/aoaPositioning.pdf)

### Trilateration

Bei der Lateration handelt es sich um eine Methode zur Positionsbestimmung, bei der die Entfernung zwischen Sender und Empfänger ermittelt wird. Durch die Entfernung zwischen Sender und Empfänger entsteht im zweidimensionalen Bereich ein Kreis um den Sender. Der Empfänger befindet sich dann auf einem Punkt dieser Kreisbahn [@Strang_2008_BOOK]. Um eine eindeutige Position zu ermitteln, sind mindestens drei Sender notwendig, weswegen diese Methode auch Trilateration genannt wird. Abbildung \ref{fig:lateration} zeigt das Verfahren: Die Position des Empfängers wurde zur besseren Darstellung nur eingekreist, er befindet sich auf dem Schnittpunkt der drei Kreise innerhalb des gestrichelten schwarzen Kreises. Der Abstand zwischen Sender und Empfänger $r$ entspricht dem Radius des Kreises um den Sender. Der Empfänger befindet sich auf einem unbestimmten Punkt der Kreislinie. Wird nun ein weiterer Sender hinzugefügt, so definieren die jeweiligen Schnittpunkte der Kreise die mögliche Position des Empfängers. Bei drei Sendern gibt es im optimalen Fall nur einen Schnittpunkt, bei dem alle drei Kreislinien aufeinander treffen. 

![2D-Positionierung mit der Trilateration. \label{fig:lateration}](../static/lateration.pdf)

Formel \ref{eq:lgsTrilateration} zeigt das allgemeine quadratische Gleichungssystem zur Berechnung der Position $p_x$ und $p_y$ bei der Trilateration [@Noertjahyana_2017]. Dabei beschreibt $x_i$ und $y_i$ die Position der Sender $i=1,2,3$ und $r_i$ den gemessenen Abstand zwischen Sender $i$ und Empfänger.

\begin{equation}\label{eq:lgsTrilateration}
\begin{aligned}
  r_1^2= (p_x-x_1)^2 + (p_y-y_1)^2 \\
  r_2^2= (p_x-x_2)^2 + (p_y-y_2)^2 \\
  r_3^2= (p_x-x_3)^2 + (p_y-y_3)^2
\end{aligned}
\end{equation}



Strang et al. haben verschiedene Verfahren zur Distanzberechnung anhand von Mobilfunkzellen vorgestellt [@Strang_2008_BOOK], diese werden im Folgenden allgemein beschrieben:

#### Laufzeitmessung {-}

Die Laufzeitmessung, besser bekannt unter dem englischen Begriff \ac{toa}, beruht auf der Messung der absoluten Signallaufzeit $t = t_i - t_0$ von einem Sender zum Empfänger. Dabei beschreibt $t_i$ die Sendezeit und $t_0$ den Empfangszeitpunkt des Signals. Zur Berechnung der Distanz $r$ wird die Lichtgeschwindigkeit $c$ mit der Laufzeit des Signals multipliziert: $r = c \cdot t$. Für diese Messung ist eine sehr genaue und zwischen Sender und Empfänger synchronisierte Zeiterfassung notwendig [@Strang_2008_BOOK]. 

#### Laufzeitdifferenzmessung {-}

Bei der Laufzeitdifferenzmessung, auch bekannt als \ac{tdoa}, wird die Differenz der Signallaufzeit zweier Sender am Empfänger gemessen. Der Vorteil gegenüber dem \ac{toa}-Verfahren liegt darin, dass keine Zeitsynchronizität zwischen dem Sender und Empfänger hergestellt werden muss. Die Laufzeitdifferenzen zwischen den Signalen zweier Sender entspricht damit der Differenz der Distanz vom Empfänger zu den beiden Sendern [@Strang_2008_BOOK].

#### Signalstärkemessung {-}

Die Messung der Signalstärke, auch bekannt als \ac{rss} ist ein gängiges Verfahren bei der Lokalisierung mithilfe von Funksystemen [@Chen_2019; @Davidson_2017a; @Ye_2019]. Hierbei wird die Empfangsleistung und damit die Dämpfung des Signals am Empfänger gemessen. Die Signaldämpfung hängt dabei unter anderem von der Distanz zwischen Sender und Empfänger ab. Zur Berechnung der Entfernung ist die Kenntnis über den mathematischen Zusammenhang zwischen Entfernung und Signaldämpfung notwendig. Diese Ausbreitungsmodelle sind für viele Szenarien bekannt [@Strang_2008_BOOK].

### Bewertung

Im Folgenden sollen die eingangs erwähnten Verfahren zur Lokalisierung hinsichtlich der Fragestellung betrachtet werden. Dabei liegt ein besonderes Augenmerk auf dem möglichen räumliches Auflösevermögen und dem Aufwand, mit dem das Verfahren implementiert und angewendet werden kann. Tabelle \ref{tab:location} bietet eine Übersicht der Bewertung der einzelnen Verfahren.

Das \ac{cellid}-Verfahren hat eine sehr geringes Auflösevermögen. Auch mit einer hohen Anzahl an Sendern bleibt die ermittelte Position nur ein diffuses Areal anstelle einer punktgenauen Lokalisierung. Der Aufwand der Umsetzung hingegen ist als eher gering einzuschätzen.

Beim Fingerprinting-Verfahren ist das Auflösungsvermögen unter anderem vom betriebenen Aufwand bei der Einrichtung abhängig. Auch die gewählten Parameter zum Erstellen des Fingerabdrucks und die Beständigkeit der Umgebung haben großen Einfluss auf das Auflösungsvermögen. Daher muss die Einrichtung bei Veränderungen an der Umgebung erneut durchgeführt werden, was den Aufwand für diese Methode stark erhöht.

Das \acl{aoa}-Verfahren lässt sich nur umsetzen, wenn das Gerät die benötigte Hardware zur Ermittlung des Eintrittswinkels mitbringt. Das Auflösungsvermögen ist dann nur von den Messfehlern, beschrieben in Abschnitt \ref{messung-fehler}, abhängig und kann somit zunächst als sehr hoch eingestuft werden. Der Aufwand ist jedoch, passende Hardware vorausgesetzt, relativ gering.

Für die Trilateration stehen mehrere Verfahren zur Auswahl. Diese unterscheiden sich hauptsächlich im Aufwand. Das Auflösungsvermögen ist, wie schon beim \ac{aoa}-Verfahren, abhängig von den Messfehlern der eingesetzten Verfahren. Dabei wird beim \ac{rss}-Verfahren ein etwas geringeres Auflösungsvermögen angenommen, da die Entfernung aufgrund der Signalstärke nicht nur durch Umwelteinflüsse, sondern auch durch das verwendete Modell beeinflusst wird. Der Aufwand für \ac{toa} und \ac{tdoa} wird mit sehr hoch angenommen, da eine genaue Zeitmessung spezielle Hardware voraussetzt. Diese Hardware ist in Smartphones nicht zu finden.

| Verfahren | mögliches Auflösungsvermögen | Aufwand |
| ------- | ------------- | ------- |
| \ac{cellid} | sehr gering | gering |
| Fingerprinting | stark schwankend | sehr hoch |
| \acl{aoa} | sehr hoch | gering |
| \acl{toa} | sehr hoch | sehr hoch |
| \acl{tdoa} | sehr hoch | sehr hoch |
| \acl{rss} | hoch | gering |
: Übersicht und Bewertung der Verfahren zur Lokalisierung nach räumlichen Auflösungsvermögen und Umsetzungsaufwand. \label{tab:location}

## Smartphone-Sensoren

Aktuelle Smartphones besitzen eine Vielzahl von Sensoren, welche die Interaktion mit der Umwelt durch Messung von Umgebungsvariablen ermöglichen. Viele der Sensoren lassen sich alleine oder in Kombination zur Entfernungsmessung oder Distanzmessung einsetzen [@Subbu_2013; @Chen_2019; @Li_2012; @SosaSesma_2016]. 

Die Entfernung zu einem Referenzpunkt, wie einer Wand, lässt sich zum Beispiel durch den Einsatz eines Sonars messen. Für die Umsetzung kommen das Mikrofon und der Lautsprecher des Smartphones in Frage [@Graham_2015]. Dies entspricht einer eindimensionalen Positionsbestimmung, deren Einsatzbereich für diese Arbeit zu unflexibel ist.

Zu den bekanntesten Sensoren zur Lokalisierung gehört das \ac{gps}. Hierbei wird mithilfe von Satelliten die Position des Smartphones ermittelt. Dies ermöglicht die Ortung außerhalb von Gebäuden mit einer Genauigkeit von wenigen Metern [@Bajaj_2002a]. Da die Messungen jedoch nicht auf den Außenbereich beschränkt sein sollen, wird \ac{gps} nicht näher betrachtet.

Die Innenraum-Lokalisierung und Navigation ist ein Forschungsfeld mit großem Interesse. Viele Arbeiten basieren auf dem vom \ac{ieee} festgelegten Standard IEEE 802.11, auch bekannt als \ac{wifi} [@Chen_2019]. Für den Einsatz von \ac{wifi} zur Lokalisierung muss zunächst eine Karte (siehe Kapitel \ref{fingerprinting}) mit der Funkstärkenverteilung erstellt werden [@Davidson_2017a]. Dies bedeutet einen hohen zeitlichen Aufwand bei der Einrichtung und eine geringe Flexibilität im Einsatz.

Ein weiterer Sensor, der zur Lokalisierung in Innenräumen häufig betrachtet wird, ist Bluetooth. Dieser ist genauso wie \ac{wifi} weit verbreitet, dabei allerdings kostengünstiger [@Ye_2019]. Im weiteren Verlauf der Arbeit soll Bluetooth näher betrachtet werden.


## Bluetooth

Bei Bluetooth handelt es sich um einen Industriestandard, der in den 1990er-Jahren durch die \ac{sig} entwickelt und eingeführt wurde. Die Technologie dient seither zur Datenübertragung zwischen verschiedenen Endgeräten mittels Funktechnik. Die Reichweite hängt maßgeblich von der Umgebung und der Sendeleistung ab und kann zwischen \SI{1}{\meter} und \SI{200}{\meter} betragen. Bluetooth arbeitet im lizenzfreiem \ac{ism} von \siacl{2.402}{ghz}{\giga\Hz} bis  \SI{2,480}{\giga\Hz}, wodurch es weltweit zulassungsfrei betrieben werden darf. Im Jahr 2020 wurde Bluetooth in 4 Milliarden verkauften Produkten verbaut [@BluetoothSIG_2021]. Darunter befinden sich Smartphones, Computer, medizinische Geräte sowie Unterhaltungsmedien und vieles mehr. Dies und die Tatsache das die \ac{sig} im Jahr 2021 36.645 Mitglieder aufweist [@BluetoothSIG_2021], lässt schlussfolgern, das Bluetooth ein etablierter Standard für den Austausch von Daten ist.

### Bluetooth Low Energy

Mit der Einführung von Bluetooth 4.0 im Juli 2010 wurde \acl{ble} in die Bluetooth Technologie integriert. Dabei ist \ac{ble} zu früheren Bluetooth-Versionen nicht abwärtskompatibel, bietet jedoch einige nützliche Besonderheiten, hierunter zählen: Ein reduzierter Stromverbrauch und die kurze Aufbauzeit einer Übertragung. Geräte wie Smartphones und Tablets unterstützen sowohl das klassische Bluetooth als auch den \acl{ble} Standard. Unterstützt ein Gerät nur den \ac{ble}-Standard, so wird es als Bluetooth Smart-Gerät bezeichnet. 

Nach einer Sichtung des Sortiments der Onlineshops Amazon und Reichelt am 18.05.2021 hat sich herausgestellt, dass die meisten Geräte den 2014 eingeführten Bluetooth-Standard 4.2 oder neuer unterstützen. Im Bluetooth-Standard 5.2 wurden einige Verbesserungen zur Lokalisierung mittels Bluetooth eingeführt: Unter anderem die Ermittlung des \acl{aoa}, was zu einer höheren Genauigkeit bei Entfernungsmessungen führen soll. Geräte mit diesem Standard, der im Dezember 2019 eingeführt wurde, sind zum Zeitpunkt der Arbeit jedoch schwer erhältlich. Da die neuen Standards 5.0, 5.1 und 5.2 abwärtskompatibel sind, wird im weiteren Verlauf Bluetooth 4.2 und seine Spezifikationen [@BluetoothSIG_2014] näher betrachtet.

Durch die stromsparenden Eigenschaften von \ac{ble} wird es häufig auch in kleinen Geräten eingesetzt, welche Daten ohne aktive Verbindung via Bluetooth übertragen. Dieses Ausstrahlen von Daten wird Advertising genannt. Ein Gerät, dass nur Advertising-Pakete aussendet, ein sogenannter Advertiser, wird auch als Beacon bezeichnet. Geräte die nach Advertising-Paketen lauschen und keine Verbindung aufbauen wollen, nennen sich Scanner [@BluetoothSIG_2014, Vol. 1 Part A S. 16].

![\ac{ble} Kanäle im \SI{2.4}{\giga\Hz} \ac{ism} und die \ac{wifi} Kanäle 1, 6 sowie 11 als Referenz (nach [@ATL_2021]). \label{fig:blechannels}](../static/ble-advertising-channels.pdf)

\ac{ble} sendet im \SI{2.4}{\giga\Hz} \ac{ism}, welches in 40 physikalische Kanäle zu je \siacl{2}{mhz}{\mega\Hz} aufgeteilt wird. Davon sind 37 Kanäle für die Datenübertragung vorgesehen sowie 3 Kanäle für das Advertising reserviert [@BluetoothSIG_2014, Vol. 1 Part A S. 16]. In Abbildung \ref{fig:blechannels} sind die \ac{ble}-Kanäle (grau und rot) den drei am häufigsten verwendeten \ac{wifi}-Kanälen (gelb) 1, 6 und 11 [@Kajita_2016] aus dem gleichen Frequenzband gegenübergestellt. Es ist zu erkennen, dass die Advertising-Kanäle (rot gekennzeichnet) außerhalb dieser \ac{wifi}-Kanäle liegen und somit wenige Störeinflüsse durch \ac{wifi} erwartet werden können.

Ein Advertising-Paket enthält 31 Bytes, die vom Nutzer frei definiert werden können. Dabei wird es jeweils auf allen drei Advertising-Kanälen versendet. Das Senden benötigt dabei weniger als \num{10} \acl{ms}n (\si{\milli\second}). Das Sendeintervall kann zwischen \SI{20}{\milli\second} und \num{10.24} \acl{s}n (\si{\second}) eingestellt werden. Tabelle \ref{tab:adpackettype} zeigt die Advertising-Pakettypen; bei Typen die keine Verbindung zulassen ist das minimal mögliche Sendeintervall auf \SI{100}{\milli\second} beschränkt [@BluetoothSIG_2014, Vol. 2 Part E S. 969 und Vol. 3 Part C S. 389].

\begin{longtable}[]{@{}llll@{}}
\caption{Übersicht über die verschiedenen Pakettypen von
Advertising-Paketen. \label{tab:adpackettype}}\tabularnewline
\toprule
\begin{tabular}[c]{@{}l@{}}Advertising- \\ \ac{pdu}\end{tabular} & \begin{tabular}[c]{@{}l@{}}Maximale\\ Datenlänge\end{tabular} & \begin{tabular}[c]{@{}l@{}}Scan Request\\Erlaubt\end{tabular} & \begin{tabular}[c]{@{}l@{}}Verbindung\\ Erlaubt\end{tabular} \\
\midrule
\endfirsthead
\toprule
\begin{tabular}[c]{@{}l@{}}Advertising- \\ \ac{pdu}\end{tabular} & \begin{tabular}[c]{@{}l@{}}Maximale\\ Datenlänge\end{tabular} & \begin{tabular}[c]{@{}l@{}}Scan Request\\Erlaubt\end{tabular} & \begin{tabular}[c]{@{}l@{}}Verbindung\\ Erlaubt\end{tabular} \\
\midrule
\endhead
ADV\_IND & 31 bytes & ja & ja \\
ADV\_DIRECT\_IND & 6 bytes & nein & ja \\
ADV\_SCAN\_IND & 31 bytes & ja & nein \\
ADV\_NONCONN\_IND & 31 bytes & nein & nein \\
\bottomrule
\end{longtable}

### Entfernungsmessung mit der Signalstärke

Die Bluetooth-Spezifikation sieht die Übertragung der Signalstärke, dem sogenannten \ac{rssi}, vor. Dabei handelt es sich um einen absoluten Wert in \ac{dbm} mit einer festgeschriebenen maximalen Abweichung von \num{\pm 6} \ac{db} [@BluetoothSIG_2014, Vol. 2 Part E S. 806]. Wie in Abschnitt \ref{trilateration} Signalstärkemessung beschrieben, ist durch den \ac{rssi}-Wert eine Entfernungsmessung realisierbar.

Zum Einsatz kommt das long-distance path loss-Modell [@Seybold_2005_BOOK]. Dabei handelt es sich um ein Modell zur Vorhersage von Signalverlusten bei der Ausbreitung von Funkwellen. In der Android Beacon library [@beacon_library_2021] findet sich Formel \ref{eq:beacondistance} zur Berechnung der Distanz $d$. Die $txPower$ entspricht dabei der Empfangsstärke auf \SI{1}{\meter} Entfernung und $P_{R_{x}}$ die empfangene Signalstärke des Beacons. Die $txPower$ wird häufig vom Hersteller angegeben und ist somit ein bekannter, fester Wert. Die Konstanten $A$, $B$ und $C$ sind empirisch ermittelte Werte, die für jede Hardwarekombination unterschiedlich sind. Standardmäßig kommen in der Android Beacon library die folgenden, auf das Smartphone Nexus 4 kalibrierten, Faktoren zum Eingesetzt: $A = 0,89976$, $B = 7,7095$ und $C = 0,111$.

\begin{equation}\label{eq:beacondistance}
\begin{aligned}
d = A \cdot \left( \cfrac{P_{R_{x}}}{txPower} \right)^{B} + C
\end{aligned}
\end{equation}

Da die Signalstärke Schwankungen unterliegt, mehr dazu im nächsten Kapitel \ref{messung-fehler}, führt die Messung der Entfernung mit einem festen Wert für $txPower$ zu größeren Abweichungen. Dies kann nach Cho et al. [@Cho_2015a] durch den Einsatz eines Kalibrierungs-Beacons im Abstand von \SI{1}{\meter} zum zu messenden Beacon optimiert werden. Dabei misst der Kalibrierungs-Beacon die aktuelle Signalstärke und übermittelt diese an den Scanner. Bei der Berechnung der Entfernung wird nun in Formel \ref{eq:beacondistance-scPower} anstelle der $txPower$ der aktuell gemessenen \ac{rssi}-Wert auf \SI{1}{\meter}, beschrieben als $scPower$, eingesetzt.

\begin{equation}\label{eq:beacondistance-scPower}
\begin{aligned}
d = A \cdot \left( \cfrac{P_{R_{x}}}{scPower} \right)^{B} + C
\end{aligned}
\end{equation}

## Messung, Fehlerquellen und -korrekturen {#messung-fehler}

Jede Messung ist fehlerbehaftet, auch wenn sie präzise durchgeführt wird. Zum Beispiel kann es schon beim Ablesen von Messdaten zu Fehlern kommen, aber auch das Einbringen eines Messgeräts kann die zu messenden Werte in einem System verändern. Aus diesem Grund ist die Beurteilung und Klassifikation von Messfehlern ein wichtiger Teil bei der Betrachtung einer Messkette [@Lerch_2006_BOOK, S. 89]. In den folgenden Abschnitten werden die notwendigen Begriffe zur Beurteilung von Fehlern eingeführt und weiter die Fehlerkorrekturmöglichkeiten betrachtet. 

### Referenzwert

In der Literatur wird häufig vom wahren Wert einer Messung im Zusammenhang mit der Fehlerbewertung gesprochen. Dieser wahre Wert ist ein Wert ohne Fehler und damit stets unbekannt, da jede Messung fehlerbehaftet ist [@jcgm_2012, Nr. 2.11]. Aus diesem Grund kommt anstelle des wahren Werts der Referenzwert zum Einsatz. Dieser Referenzwert wird mithilfe bekannter, möglichst genauer Messmethoden ermittelt. Für die Entfernung sind dies beispielsweise Maßbänder oder digitale Entfernungsmessgeräte. Dabei kommt es sowohl beim Ablesen als auch beim Anhalten des Maßbandes zu Ungenauigkeiten, was die Ermittlung des wahren Werts unmöglich macht. In den folgenden Kapiteln und insbesondere in den Formeln wird aus diesem Grund nicht der wahre Wert, sondern der Referenzwert verwendet. Dieser Referenzwert stimmt dabei ungefähr mit dem wahren Wert überein [@jcgm_2012, Nr. 5.18].

### Arten von Messfehlern

Messfehler werden in systematische und zufällige Fehler unterschieden: 

**Systematische Fehler** sind vorhersagbar und somit auch korrigierbar. Sie unterteilen sich in statische Messfehler und dynamische Messfehler. Statische Messfehler haben einen konstanten Betrag und ein bestimmtes Vorzeichen, dynamische Messfehler hingegen resultieren in einer zeitlichen Veränderung des Messwertes einer Messreihe. Da systematische Fehler prinzipiell korrigierbar sind, sollten sie nach Möglichkeit im ersten Schritt der Messwertverarbeitung berichtigt werden [@Lerch_2006_BOOK, S. 90].

**Zufällige Messfehler** lassen sich hingegen nicht unmittelbar erfassen. Die Abweichungen vom wahren Wert können nur in Form von Wahrscheinlichkeitsaussagen beschrieben werden. Um diesen Fehlertyp zu beurteilen, müssen möglichst viele Messungen durchgeführt werden. Nach dem zentralen Grenzwertsatz ergibt sich hierbei in der Regel eine Normalverteilung nach Gauß. Das Normalverteilungsgesetz für zufällige Fehler ist dabei wie folgt charakterisiert: positive und negative Abweichungen treten gleich häufig auf, die Wahrscheinlichkeit des Auftretens einer Abweichung nimmt mit zunehmender Größe der Abweichung ab [@Lerch_2006_BOOK, S. 91].

Nachfolgend sollen Beispiele für die beiden Fehlerarten genannt und beschrieben werden. Tabelle \ref{tab:error} gibt eine Übersicht über die verschiedenen Fehler.

#### Beispiele systematischer Fehler {-}

- **Hindernisse**: Wände, Möbel, Pflanzen, Menschen und andere Objekte beeinflussen die Ausbreitung von Funkwellen. Der Einfluss äußert sich in Abschwächung oder Reflektion des Signals. Bei Reflektionen kann es zum mehrfachen Empfang eines Signals kommen. Dabei hat das reflektierte Signal meist einen weiteren Weg hinter sich und ist daher schwächer. Die zusätzliche Abschwächung des Signals durch Objekte zwischen Sender und Empfänger, führt zu einem schwächeren Signal am Empfänger und beeinflusst so die Entfernungsmessung mithilfe der Signalstärke.
- **Reflektionen**: Alle Objekte, speziell metallische, können Funkwellen reflektieren. Diese Reflektionen können zur Mehrfachmessung eines Signals führen.
- **Smartphone-Gehäuse**: Wie Hindernisse wirkt sich auch das Smartphone-Gehäuse sowie die verbauten Sensoren im Smartphone auf die Signalstärke aus. Auch eine Smartphone-Hülle, die vom Nutzer angebracht wird, kann die Signalstärke beeinflussen. Da die meisten Hüllen aus Plastik bestehen, ist dieser Effekt jedoch als gering anzusehen.
- **Antennenanordnung**: Sowohl die Orientierung als auch die Position der Antenne beeinflussen die Qualität des empfangenen Signals. Liegt die Antenne beispielsweise auf der linken Seite des Smartphones, so werden Signale, die von rechts kommen stärker gedämpft, vergleichend hierzu die Abbildung der Empfangscharakteristik in [@Raytac_2021, S. 30 Antenna].
- **RSSI Sensor**: Die Signalmessung wird durch den Bluetooth Chip durchgeführt. Dieser nutzt einen 8-bit \ac{adw}, um einen Wert zwischen 0 und 255 zu erhalten. Das stärkste Signal wird durch den Wert 255 abgebildet. Bei der Umrechnung dieses Wertes in \ac{dbm} muss für gute Ergebnisse ein angepasster Code verwendet werden. Ob und wie gut diese Anpassung geschieht, hängt allein vom Hersteller ab.
- **Versuchsaufbau**: Auch der Aufbau des Versuchs kann zu Fehlern im System führen. Dieser systematische Fehler kann meist nur durch die Wiederholung der Versuche korrigiert werden.

#### Beispiele zufälliger Fehler {-}

- **Funkrauschen**: \ac{ble} verwendet den selben Frequenzbereich wie \ac{wifi} und viele weitere Funktechnologien für den Konsumerbereich. Auch andere Signale von unterschiedlichen Frequenzbereichen strahlen teilweise in diesen Frequenzbereich ein. Dabei kann diese starke Auslastung dazu führen, dass Pakete nicht empfangen werden oder die Empfangsstärke beeinflusst wird [@Heilmann_2020_BOOK].
- **Bluetooth Channel Rotation**: \ac{ble} nutzt drei verschiedene Kanäle, mit unterschiedlichen Frequenzen, für das Advertising. Die Antennen sind jedoch auf eine bestimmte Frequenz optimiert. Daher kommt es zu Abweichungen beim \ac{rssi} je nach verwendetem Advertising-Kanal [@Paterna_2017]. Dies ist prinzipiell ein systematischer Fehler der korrigierbar wäre. Unter Android gibt es derzeit jedoch keine Möglichkeit den Kanal auszulesen, weswegen der Fehler damit zufällig auftritt.

| Fehler     |  Fehlerart | Ursache        |
| ---------- |  --------- | -------------------- |
| Hindernisse |  systematisch | physikalisch  |
| Reflektionen |  systematisch | physikalisch |
| Smartphone-Gehäuse | systematisch | physikalisch | 
| Antennenanordnung | systematisch | physikalisch, konstruktiv |
| RSSI Sensor | systematisch | Implementierung |
| Versuchsaufbau | systematisch |  Mensch |
| Funkrauschen | zufällig | physikalisch |
| Bluetooth Channel Rotation | systematisch/zufällig | Implementierung |
: Übersicht der Fehler, Fehlerarten und Ursache \label{tab:error}

### Genauigkeit einer Messung

Die Genauigkeit einer Messung wird durch die Richtigkeit und die Präzision beschrieben. Dabei hat ein Messwert eine hohe Genauigkeit, wenn sowohl eine hohe Richtigkeit, als auch eine hohe Präzision vorliegt.

![Zusammenhang zwischen Richtigkeit und Präzision. \label{fig:genauigkeit}](../static/genauigkeit.pdf)

Die Richtigkeit lässt eine Aussage über die Nähe von Einzelmesswerten zum tatsächlichen Messwert zu. Bei einer guten Richtigkeit stimmen die gemessenen Werte im Mittel mit dem tatsächlichen Messwert nahezu überein. In Formel \ref{eq:richtigkeit} wird die Richtigkeit mathematisch beschrieben. Sie wird dabei durch den Betrag der Differenz aus dem Mittelwert $\overline{x}$ der gemessenen Werte und dem Referenzwert $R$ beschrieben.

\begin{equation}\label{eq:richtigkeit}
\text{Richtigkeit}=|\overline{x}-R|
\end{equation}

Die Präzision beschreibt die Streuung der Messwerte um den Mittelwert. Je näher die Messwerte beieinander liegen, desto höher die Präzision. Die Streuung wird dabei durch zufällige Fehler ausgelöst und kann durch die relative Standardabweichung ausgedrückt werden.

Die Abhängigkeit von Präzision und Richtigkeit wird in Abbildung \ref{fig:genauigkeit} verdeutlicht. Dabei liegt der tatsächliche Wert jeweils im Zentrum der Kreise. Nur das Szenario rechts oben in der Abbildung hat eine hohe Genauigkeit, da es sowohl eine hohe Präzision, als auch eine hohe Richtigkeit aufweist. Alle anderen Szenarien haben eine geringe Genauigkeit, können jedoch eine hohe Präzision oder eine hohe Richtigkeit oder keins von beidem (unten links) aufweisen.

### Fehlerbewertung

Eine weitere Kenngröße, die eine Aussage über die Qualität der Messung liefert, ist der Messfehler [@Lerch_2006_BOOK, S. 89]. Er wird unterteilt in einen absoluten und relativen Fehler. Der absolute Fehler $F$ in Formel \ref{eq:abs-fehler} definiert sich durch die Differenz zwischen dem Messwert $M$ und dem Referenzwert $R$ und gibt Auskunft über die absolute Abweichung zwischen den beiden Werten.

\begin{equation}\label{eq:abs-fehler}
F=M-R
\end{equation}

Der relative Fehler $f$ in Formel \ref{eq:rel-fehler} wird in Prozent angegeben und ermittelt sich aus dem absoluten Fehler $F$ bezogen auf den Referenzwert $R$.

\begin{equation}\label{eq:rel-fehler}
f=\cfrac{F}{R} \cdot 100
\end{equation}

Bei der Lokalisierung ist unter anderem die Beurteilung der Abweichung des gemessenen Punkts zum Referenzpunkt wichtig. Mit Formel \ref{eq:abstand} lässt sich der Abstand $d$ zwischen der gemessenen Position $(M_x,M_y)$ und der Referenzposition $(R_x,R_y)$ ermitteln. $d$ ist somit die absolute Abweichung der Lokalisierung $F_{loc}$. Aus den Formeln \ref{eq:abs-fehler} und \ref{eq:rel-fehler} sowie der Kenntnis über die absolute Abweichung in Formel \ref{eq:abstand} ergibt sich die relative Abweichung $f_{loc}$ in Formel \ref{eq:loc-fehler}.

\begin{equation}\label{eq:abstand}
d=F_{loc}=\sqrt{(M_x-R_x)^2 + (M_y-R_y)^2}
\end{equation}

\begin{equation}\label{eq:loc-fehler}
f_{loc}=\sqrt{\cfrac{(M_x-R_x)^2 + (M_y-R_y)^2}{R_x^2+R_y^2}} \cdot 100
\end{equation}

### Kalibrierung

Eine Methode zur Reduzierung von systematischen Fehlern, beschrieben in Abschnitt \ref{arten-von-messfehlern} Systematische Fehler, ist die Kalibrierung. Hierbei werden mehrere Messreihen mit möglichst vielen Messungen angefertigt. Es wird darauf geachtet, dass die äußeren Einflüsse, die auf die Messung einwirken können, weitestgehend eliminiert werden und die Messumgebung stets gleich bleibt. Durch eine hohe Anzahl von Messungen kann der statistische Fehler zusätzlich minimiert werden [@jcgm_2012, Nr. 2.19]. Sollte der Mittelwert der Messung nun nicht mit dem Referenzwert übereinstimmen, so ist diese Abweichung auf einen systematischen Fehler zurückzuführen. Um die Linearität des Fehlers zu beurteilen, müssen mehrere Messreihen mit unterschiedlichen Eingangsvoraussetzungen betrachtet werden. Die Eingangsvoraussetzungen sind vom betrachteten System abhängig, im Fall der Entfernungsmessungen werden Messreihen mit unterschiedlichen Abständen angefertigt. Aus den gewonnenen Daten können so Korrekturfaktoren ermittelt werden, welche den systematischen Fehler reduzieren [@jcgm_2012, Nr. 2.39, Nr. 3.11].

### Filter

Die unverarbeiteten Messwerte werden als Rohdaten bezeichnet. Sie sind aufgrund der zuvor beschriebenen Messfehler nicht zur Anzeige geeignet. Um den Einfluss der Fehler zu reduzieren, werden im ersten Schritt die systematischen Fehler minimiert. Im nächsten Schritt gilt es die zufälligen Fehler, also stark gestreute Werte und Rauschen, zu detektieren und zu eliminieren. Hierbei kommen verschiedene Filterverfahren zum Einsatz, die einzeln oder in Kombination eingesetzt werden können. Im Folgenden werden zwei Filtermethoden beschrieben, die im Rahmen dieser Arbeit untersucht werden sollen.

#### Gleitender Mittelwert {-}

Beim gleitenden Mittelwert handelt es sich um eine Methode zur Glättung von zeitlichen Datenreihen. Er basiert auf der Annahme, dass sich die zu messende Größe über den zeitlichen Verlauf nicht sprunghaft ändert. Diese Annahme trifft auch auf den \ac{rssi}-Wert zu.

Formel \ref{eq:gleitendME} zeigt die mathematische Umsetzung des gleitenden Mittelwerts $m_i$. $q$~beschreibt dabei die Anzahl an Werten die unmittelbar vor und nach dem aktuellen Messwert $x_i$ erfasst wurden. Zur Ermittlung des arithmetischen Mittelwertes wird die Wertereihe $x_{i-q}, ...., x_{i+q}$ betrachtet. Die Größe des Fensters $q$ ist ein Parameter der zu Beginn festgelegt werden muss. Dabei ist zu beachten: Ein kleiner Wert für $q$ erhöht das Rauschen und ein großer Wert kann dazu führen, dass kleine Änderungen zu stark ausgeglichen und somit nicht erkannt werden können.

\begin{equation}\label{eq:gleitendME}
m_i = \frac{1}{2q+1} \sum_{k=i-q}^{i+q} x_k
\end{equation}

Bei zeitlichen Messreihen werden die Messdaten oft nicht in zeitlich konstanten Abständen gemessen. Aus diesem Grund sollte das Fenster $q$ nicht die feste Anzahl von Messwerten sondern, ein Zeitintervall $q_t$ beschreiben. Somit ergibt sich aus Formel \ref{eq:gleitendME} der auf Zeit basierende gleitende Mittelwert $m_{i_t}$ in Formel \ref{eq:gleitendTime}. Der Wert $A$ ist die Anzahl an Datenpunkten, die im Zeitfenster $i_t-q_t$ bis $i_t+q_t$ in die Messung einbezogen werden. $i_t$ beschreibt den Zeitpunkt der betrachteten Messung.

\begin{equation}\label{eq:gleitendTime}
m_{i_t} = \frac{1}{A} \sum_{k=i_t-q_t}^{i_t+q_t} x_k
\end{equation}

#### Gewichteter Mittelwert {-}

In den Sozialwissenschaften finden Wichtungen häufig Anwendung und sind trotz der unterschiedlichen wissenschaftlichen Disziplinen in mathematischer Hinsicht auch im technischen Bereich nutzbar. Demnach können Wichtungsfaktoren grundsätzlich auf zwei unterschiedliche Arten bestimmt werden. 

| Messwerte Verteilung \si{\percent} | SOLL \si{\percent} | Beispiel für eine IST Verteilung \si{\percent} | Wichtungsfaktor (SOLL/IST) 
| ------------ | ----------- | ----------------- | ------------ |
| 0-25  | 5   | 15 |   0,333    |
| 25-50 			  | 10  | 25 |   0,4      |
| 50-75  | 25  | 25 |   1        |
| 75-100  | 60  | 40 |     1,5      |
: Beispiel für die Ermittlung des Wichtungsfaktors durch SOLL/IST Vergleich. \label{tab:wichtungsfaktor}

Im ersten Fall ist eine Verteilung der Grundgesamtheit bekannt. Im zweiten Fall ist die Grundgesamtheit nicht bekannt, so dass die Verteilung geschätzt werden muss [@Alt_1994a]. Der Wichtungsfaktor wird im zweiten Fall durch das Soll-Wert/Ist-Wert Verhältnis ermittelt. Ein Beispiel ist in Tabelle \ref{tab:wichtungsfaktor} zu finden. Dabei wird angenommen, dass Messwerte im oberen Viertel zu \SI{5}{\percent} vorkommen können, im unteren Viertel zu \SI{60}{\percent}.

Formel \ref{eq:weighted} beschreibt die allgemeine mathematische Umsetzung des gewichteten Mittelwerts $m_w$. Dabei wird im betrachteten Messwertebereich $q$ jedem Messwert $x_i$ je nach seinem IST ein Wichtungsfaktor $w_i$ zugeteilt. Der gewichtete Mittelwert ergibt sich aus der Summe des Produkts von Wichtungsfaktor und Messwert geteilt durch die Summe der Wichtungsfaktoren. 

\begin{equation}\label{eq:weighted}
m_{w} = \frac{\sum\limits_{k= i-q}^{i+q} w_k \cdot x_k}{\sum\limits_{k= i-q}^{i+q} w_k}
\end{equation}

# Implementierung

In den folgenden Abschnitten wird die verwendete Hardware sowie die Implementierung beschrieben. Zum Einsatz kommen die Programmiersprachen JavaScript, Python und Kotlin. Dieser Mix wird in den nächsten Abschnitten verständlich und ergibt sich aus der gewählten Hardware und dem Vorgehen.

## Beacons

Als Bluetooth-Beacons kommen Puck.js [@puckjs], Abbildung \ref{fig:puck}, der Firma Espruino zum Einsatz. Die Beacons basieren auf einer offenen Plattform und bieten neben Bluetooth noch weitere Sensoren wie: ein Magnetometer zur Messung von Magnetfeldern, ein Accelerometer zur Messung von Beschleunigungen, ein Gyroscope zur Messung der Winkelgeschwindigkeit, einen Temperatursensor und vieles mehr. Durch diese Sensoren kann der Beacon auch für weitere Anwendungen eingesetzt werden, was jedoch nicht Bestandteil dieser Arbeit sein soll.

![Puck.js inklusive Gehäuse. \label{fig:puck}](../static/puckjs.jpeg)

Durch eine Programmierschnittstelle lässt sich der Beacon mithilfe von JavaScript programmieren. Der Einstieg wird durch ein ausführlich dokumentiertes \ac{api} sowie einer Datenbank mit Beispielprogrammen erleichtert [@Ltd_2017]. Zur Programmierung wird der Beacon mittels Bluetooth mit der integrierten Entwicklungsumgebung (\acs{ide}) im Browser verbunden. Abbildung \ref{fig:ide} zeigt die \acs{ide}: links befindet sich die Konsole, über die einzelne Befehle direkt auf dem Beacon ausgeführt werden können. Rechts ist der Editor zu sehen, in diesem können die Befehle zu Programmen zusammengeführt werden. Der Programmcode kann sowohl temporär zum Testen auf den Beacon geladen werden, als auch nach dem Test im Flash des Beacons gespeichert werden. Bei der temporären Ausführung ist der Code nach einem Batteriewechsel nicht mehr auf dem Beacon. Diese Art der Entwicklung macht das Experimentieren mit den Bluetooth-Beacons sehr einfach.

![Screenshot der Espruino \ac{ide} im Chrome-Browser. \label{fig:ide}](../static/espruino_ide.png)

### Modi

Während der Versuche mit den Beacons wird ein hohes Advertising-Intervall benötigt, um viele Advertising-Pakete in kurzer Zeit zu versenden. Dies erhöht die Messgenauigkeit bei kurzer Messdauer, führt jedoch zu einer kürzeren Batterielebensdauer. Um die Batterie nicht zu stark zu belasten, wurden zwei Modi entwickelt: Durch den integrierten Button, kann zwischen dem Versuchsmodus und dem Programmiermodus gewechselt werden. Zur Visualisierung in welchem Modus sich der Beacon befindet wird die eingebaute grüne und rote LED verwendet. Beim Wechsel vom Programmiermodus in den Versuchsmodus leuchtet die grüne LED auf und blinkt dann alle \SI{10}{\second}. Wird der Button erneut gedrückt, zeigt die rote LED das Beenden des Versuchsmodus an und der Beacon wechselt in den Programmiermodus zurück.

### Identifizierung

Jeder Beacon verfügt über eine einzigartige Hardware-Adresse, \ac{mac}-Adresse genannt. Zur einfachen Identifizierung werden die letzten zwei Byte der \ac{mac}-Adresse in Kleinbuchstaben als Kurzname der Beacons verwendet. Für das Advertising wird vor den Kurznamen ein ``BLE`` für \acl{ble} gesetzt. Tabelle \ref{tab:devices} listet die \ac{mac}-Adresse sowie den dazugehörigen Advertising-Namen und Kurznamen der Beacons auf. Im Versuchsmodus wird der Advertising-Name nicht mit ausgesendet, mehr dazu im Kapitel \ref{advertising}.

| \ac{mac}-Adresse | Advertising-Name | Kurzname |
| ---------------- | --------- | -------- |
| C6:13:E8:3F:69:0F | BLE 690f | ``690f`` |
| CD:10:9A:4C:9D:31 | BLE 9d31 | ``9d31`` |
| D6:7C:70:1C:5B:5B | BLE 5b5b | ``5b5b`` |
: Übersicht der \ac{mac}-Adressen und zugehörigen Namen der verwendeten Beacons. \label{tab:devices}

Weiterhin wird für das Advertising ein universeller Identifikator benötigt. Diese erlaubt es die Advertising-Pakete eindeutig zuzuordnen. Espruino bietet hierzu eine reservierte 16 Bit \ac{uuid} ``0x0590`` für die Entwicklung von Anwendung mit ihrer Hardware. Diese \ac{uuid} wird zur Filterung der Advertising-Pakete im Scanner verwendet.

### Advertising

Für das Advertising stehen 31 Byte für benutzerdefinierte Daten zur Verfügung. Davon werden 5 Byte im Versuchsmodus benötigt. Das Advertising-Paket im Versuchsmodus setzt sich aus der 16 Bit langen \ac{uuid} ``0x0590`` und 3 Byte zur Übertragung der $scPower$ zusammen. Die $scPower$ wird in einer festen Reihenfolge abgespeichert und übertragen. Für einen produktiven Einsatz sollten diese Werte eindeutig gekennzeichnet werden. Hierfür sind weitere 26 Byte in dem Advertising-Paket frei.

Für den Versuchsmodus wird der Beacon in den Advertising-\ac{pdu} ``ADV_NONCONN_IND``, beschrieben in Kapitel \ref{bluetooth-low-energy}, gesetzt. Hierbei lässt der Beacon keine Verbindung zu und reagiert nicht auf Anfragen, sondern sendet nur Advertising-Pakete aus. Das maximale Advertising-Intervall ist in diesem Modus zwar auf \SI{100}{\milli\second} beschränkt, dies ist jedoch für den gewählten Versuchsaufbau ausreichend. Zur Erfassung der Position bewegter Objekte sollte eine aktive Verbindung genutzt werden, da hier das Advertising-Intervall auf \SI{20}{\milli\second} verkürzt werden kann. Der Advertising-Name des Beacons wird im Versuchsmodus nicht ausgesendet.

Im Programmiermodus befindet sich der Beacon im Advertising-\ac{pdu} ``ADV_IND``. Dieser ist notwendig, damit eine Verbindung mit dem Beacon zur erneuten Programmierung hergestellt werden kann. Auch der Advertising-Name des Beacons wird in diesem Modus mit ausgesendet, um das Gerät leichter zu identifizieren.

### Verarbeitung der $scPower$

Zur Umsetzung eines selbst korrigierenden Systems müssen die Bluetooth-Beacons sowohl als Scanner wie auch als Advertiser fungieren. Im Versuchsmodus scannen die Beacons hierzu, parallel zum Aussenden der Advertising-Pakete, nach solchen Paketen von den anderen beiden Beacons. Abbildung \ref{fig:selfcorrecting} zeigt schematisch den Ablauf des selbst korrigierenden Systems anhand der Beacons ``A`` und ``B``. Der Beacon ``A`` sendet sein Advertising-Paket aus, welches von dem Beacon ``B`` empfangen und verarbeitet wird. Der Beacon ``B`` speichert den \ac{rssi}-Wert des empfangenen Pakets von Beacon ``A`` als $scPower$ in seinem Advertising-Paket und sendet dieses aus. Bei jedem erneuten Empfang eines Advertising-Pakets von Beacon ``A`` wird die $scPower$ aktualisiert. 

![Ablauf des Advertisings am Beispiel von zwei Beacons. \label{fig:selfcorrecting}](../static/Ablaufplan-Advertising.pdf){ width=60% }

## Smartphone

Als Smartphone für die Messungen kommt ein OnePlus 7t mit Android-Betriebssystem in der Version 11 zum Einsatz. Für die Anwendungsentwicklung wird die \ac{ide} Android Studio verwendet. Als Programmiersprache wurde Kotlin gewählt und die Smartphone-Anwendung als Bluetooth-Scanner umgesetzt. 

Über die Benutzeroberfläche, zu sehen in Abbildung \ref{fig:appfrontend}, müssen 4 Eingabefelder vor dem Versuchsstart ausgefüllt werden. Der Testname dienst sowohl zur späteren Zuordnung wie auch als Dateiname, unter dem die Messdaten gespeichert werden. In den weiteren Feldern wird die, für den durchgeführten Versuch, real gemessene Entfernung zwischen Smartphone und dem jeweiligen Beacon notiert. Sollten ein oder mehrere Beacons im durchgeführten Versuch keine Relevanz haben, so muss hier eine 0 eingetragen werden. Über den Start/Stop-Button am unteren Bildschirmrand der Anwendung wird die Aufzeichnung gestartet. Nach dem Start können die empfangenen Daten im oberen Bildschirmbereich zur Funktionsüberprüfung eingesehen werden. Diese Daten aktualisieren sich automatisch mit jedem empfangenen Advertising-Paket.

![Screenshot der Smartphone-Testanwendung: Bluetooth Advertise Logger. \label{fig:appfrontend}](../static/appfrontend.jpg){ height=400px }

Beim Empfang eines Advertising-Pakets wird geprüft, ob das Paket von einem der Beacons versendet wurde. Hierzu wird zunächst nach der \ac{uuid} gefiltert und anschließend nach den \ac{mac}-Adressen der drei verwendeten Beacons. Ist das Paket von einem der Beacons, so werden die Daten des Advertising-Pakets in einer Textdatei, mit dem Testnamen als Dateinamen, auf dem Smartphone abgelegt. Die Daten werden im \ac{csv}-Format gespeichert. In Tabelle \ref{tab:datastore} werden die Spalten aufgelistet und ihr Inhalt  kurz erläutert.

| Spalte | Beschreibung |
| --------- | ----------------------- |
| Time | Empfangszeitpunkt als Unix-Zeitstempel |
| Test | Benutzerdefinierter Name des durchgeführten Tests |
| Device | \ac{mac}-Adresse des Beacons |
| RSSI | Vom Smartphone ermittelter \ac{rssi}-Wert |
| 5b5b_dist | gemessene Referenzentfernung zum Beacon 5b5b |
| 5b5b_rssi | Ermittelte $scPower$ des Beacons 5b5b |
| 690f_dist | gemessene Referenzentfernung zum Beacon 690f |
| 690f_rssi | Ermittelte $scPower$ des Beacons 690f |
| 9d31_dist | gemessene Referenzentfernung zum Beacon 9d31 |
| 9d31_rssi | Ermittelte $scPower$ des Beacons 9d31 |
: Spaltenübersicht der gespeicherten \ac{csv}-Datei bei aktiver Messung. \label{tab:datastore}


## Auswertung

Die Auswertung der Messreihen wird auf dem Computer durchgeführt. Dies bietet im Gegensatz zur direkten Auswertung auf dem Smartphone den Vorteil, auch im Nachhinein Änderungen vornehmen zu können. Als Programmiersprache kommt Python zum Einsatz, welche eine Vielzahl an Bibliotheken zur Arbeit mit großen Datenmenge und zur wissenschaftlichen Auswertung bereithält.

### Daten einlesen

In einem ersten Schritt werden die Daten eingelesen und bereinigt. Zur Bereinigung werden die ersten \SI{5}{\second} und die letzten \SI{10}{\second} der Messreihe entfernt, um den Einfluss durch die Bedienung des Smartphones aus den Messreihen zu beseitigen. Bei der Übermittlung der Daten werden nicht vorhandene Messdaten mit einer 0 initialisiert. Dies würde bei Berechnungen zu Fehlern führen, weswegen alle 0-Werte aus den eingelesenen Daten gelöscht werden.

Um mit den Daten einfacher arbeiten zu können und eine bessere Übersicht zu erhalten, werden die Spalten aus Tabelle \ref{tab:datastore} umgeformt. Hierzu wird der Referenzpunkt aus den Referenzentfernungen zu den Beacons ermittelt und in der neuen Spalte ``realPosition`` gespeichert. Die Referenzentfernung sowie die $scPower$ zu dem jeweiligen Beacon wird ausgelesen und in den Spalten ``deviceDistance`` und ``scPower`` abgelegt.

Im letzten Schritt werden überflüssige Spalten gelöscht. Tabelle \ref{tab:dataclean} zeigt die vorhandenen Spalten nach dem Einlesen.

| Spalte | Beschreibung |
| --------- | ----------------------- |
| ``Time`` | Empfangszeitpunkt als Unix-Zeitstempel |
| ``Test`` | Benutzerdefinierter Name des durchgeführten Tests |
| ``Device`` | \ac{mac}-Adresse des Beacons |
| ``RSSI`` | Vom Smartphone ermittelter \ac{rssi}-Wert |
| ``scPower`` | Ermittelter \ac{rssi}-Referenzwert der benachbarten Beacon auf \SI{1}{\meter} | 
| ``deviceDistance`` | Physisch ermittelte Entfernung zwischen dem Beacon und Smartphone |
| ``realPosition`` | x,y Koordinaten des Smartphones, ermittelt durch die deviceDistance |
: Spaltenübersicht der Messreihen nach dem Einlesen der Daten. \label{tab:dataclean}

### Ermittlung der Messwerte

Die zeitlichen Abstände sowie die Reihenfolge der Advertising-Pakete sind zufällig (vgl. Abb. \ref{fig:messreihe}). Die Beacons senden zwar in einem konstanten Intervall von \SI{100}{\milli\second}, jedoch kann es bei der Übertragung zu Kollisionen kommen. Auch Aussetzer in der Übertragung oder andere Störeinflüsse führen zum Ausbleiben eines Advertising-Pakets. Um bei Berechnungen aus den Messdaten stets alle eingesetzten Beacons zu berücksichtigen, wird ein Fenster aus \SI{400}{\milli\second} betrachtet. Der zu betrachtende Messwert wird dabei aus einem Fenster von \SI{\pm 200}{\milli\second} gemittelt. Die Wahl der Fenstergröße wurde durch folgende Überlegungen getroffen: Das Fenster sollte nicht zu groß sein, um Schwankungen in den Messdaten möglichst wenig zu beeinflussen (vgl. Abschnitt \ref{filter}); Das Fenster sollte nicht zu klein sein, so dass möglichst immer alle 3 Beacons in dem betrachteten Messausschnitt enthalten sind.

![Ausschnitt aus einer Messreihe. \label{fig:messreihe}](../static/Messreihe.png){width=95%}

### Umsetzung der Trilateration

Zur Umsetzung der Trilateration wird das Gleichungssystem aus Formel \ref{eq:lgsTrilateration} zu $p_x$ und $p_y$ aufgelöst. Zur Vereinfachung wird die Position des ersten Beacons auf $x_1 = 0$ und $y_1 = 0$ und die $y$-Koordinate des zweiten Beacons auf $y_2 = 0$ gesetzt. Es entstehen die Formeln \ref{eq:trilaterationAlgorithmus}, welche aus den ermittelten Abständen $r_1$, $r_2$ und $r_3$ zu den jeweiligen Beacons die Positionen $p_x$ und $p_y$ errechnen.

\begin{equation}\label{eq:trilaterationAlgorithmus}
\begin{aligned}
  p_x &= \frac{r_1^2 - r_2^2 + x_2^2}{ 2 \cdot x_2 } \\
  p_y &= \frac{r_1^2 - r_3^2 + (x_3^2 + y_3^2) - (2 \cdot x_3 \cdot p_x)}{2 \cdot y_3}
\end{aligned}
\end{equation}

![Auswirkungen verschiedener Eingabevariablen auf die Lokalisierung durch den verwendeten Lokalisierungsalgorithmus. \label{fig:locationAlgorithmTest}](../static/Lokalisierungstest.pdf){ width=95% }

Da die Entfernungsermittlung fehlerbehaftet ist, können verschiedene Szenarien auftreten, auf die der angewandte Algorithmus überprüft werden muss. Abbildung \ref{fig:locationAlgorithmTest} zeigt die einzelnen Szenarien, die im Folgenden kurz beschrieben werden. Die blauen Punkte markieren die Positionen der Beacons, welche von einem roten Kreis eingefasst sind. Der Radius der Kreise entspricht den Abständen $r_1$, $r_2$ und $r_3$ zu den Beacons. Der ermittelte Punkt $p_x, p_y$ wird als roter Punkt dargestellt:

1. Die Kreise haben einen eindeutigen Schnittpunkt (oben links, unten rechts)
2. Die Kreise haben gar keinen Schnittpunkt (oben mitte)
3. Die Kreise schneiden sich alle, jedoch nicht an einem gemeinsamen Punkt (oben rechts, unten links)
4. Die Kreise schneiden sich teilweise (unten mitte)

In Abbildung \ref{fig:locationAlgorithmWorking} ist die Vorgehensweise des Algorithmus veranschaulicht. Um jeden Beacon wird ein Kreis mit der ermittelten Entfernung gezogen. Wenn sich zwei Kreise schneiden, wird eine Gerade (schwarz dargestellt) durch diesen Schnittpunkt gelegt. Gibt es keinen solchen Schnittpunkt, werden die beiden beteiligten Beacons durch eine Linie verbunden (hellblau dargestellt). Ausgehend vom dritten Beacon, wird eine Gerade im \SI{90}{\degree} Winkel durch diese Verbindungslinie gezogen. Die ermittelte Position ist der Punkt, an dem sich alle drei Geraden schneiden.

![Ermittlung der Position bei sich nicht überschneidenden Kreisen. \label{fig:locationAlgorithmWorking}](../static/LocationAlgorithmWorking.pdf){ width=95% }

### Filter-Implementierung

Bei der Filterung der Messdaten wird wie in Abschnitt \ref{ermittlung-der-messwerte} ein gleitendes Fenster eingesetzt. Da durch die Filter eine Glättung der Messwerte erfolgen soll, kommt ein größeres Fenster von \SI{800}{\milli\second} zum Einsatz. Das Fenster setzt sich aus \SI{600}{\milli\second} vor dem betrachteten Messwert und \SI{200}{\milli\second} nach dem betrachteten Wert zusammen. Das Fenster wurde gewählt, um eine geringe Verzögerung zu simulieren, welche bei einer späteren Implementierung wichtig ist, um die Ergebnisse während der Messung anzuzeigen.

Zum Einsatz kommen ein gleitender Mittelwert und ein gewichteter Mittelwert (beschrieben in Abschnitt \ref{filter}). Der gleitende Mittelwert wird aus dem, im vorrangegangenen Absatz beschriebenen gleitenden Fenster gebildet. Dabei wird der Datensatz in einzelne Datensätze je Beacon aufgeteilt und berechnet. Im Folgenden sollen die Überlegungen und die Umsetzung des gewichteten Mittelwerts näher beschrieben werden. 

Beim \ac{rssi}-Wert handelt es sich um einen Dämpfungsfaktor. Die Einflüsse bzw. Faktoren wurden in Abschnitt \ref{arten-von-messfehlern} beschrieben. Die Dämpfung eines Signals erhöht sich mit jedem weiteren Einflussfaktor. Es ist zu erwarten, dass bei konstanten Messbedingungen Abweichungen durch Streuung auftreten. Daher ist anzunehmen, dass geringere Dämpfungswerte den realen Zustand besser beschreiben als hohe Dämpfungswerte. Der Einsatz des gewichteten Mittelwertfilters soll dafür sorgen, dass niedrigen Dämpfungsfaktoren ein höheres Vertrauen zuteil wird, indem diese stärker gewichtet in die Berechnung des Mittelwertes einfließen.

Durch das Sendeintervall von \SI{100}{\milli\second} besteht der betrachtete Datensatz im besten Fall aus 8 Messwerten. Der \ac{rssi}-Wert ist ein absoluter, diskreter Wert und weist in der betrachteten Messreihe von ca. 8 Messwerten oft nur eine geringe Schwankung auf. Aus diesem Grund wird von der Anwendung einer kontinuierlichen Gewichtung abgesehen und eine fixe Gewichtung vorgenommen. Dabei wird wie folgt gewichtet:

- Sind alle Werte gleich groß, so wird dieser Wert zurückgegeben.
- Sind zwei verschiedene Werte im Datensatz, so wird das stärker Dämpfungsfaktor einfach und der schwächere Dämpfungsfaktor 4-Fach gewichtet.
- Sind drei oder mehr verschiedene Werte im Datensatz, so werden die stärksten Dämpfungsfaktoren einfach, die mittleren 2-Fach und die schwächsten 4-Fach gewichtet.

Dieses Vorgehen ergibt sich aus der Betrachtung einer \ac{rssi}-Werte-Verteilung wie in Abbildung \ref{fig:rssi-verteilung}. Die Verteilung der Dämpfungswerte entspricht näherungsweise einer logarithmischen Normalverteilung. Aus dem Verhältnis der Häufigkeit der Dämpfungsfaktoren in den einzelnen Intervallen, lassen sich somit die Gewichtungsfaktoren ermitteln. Da es sich bei den Messwerten um eine diskrete Verteilung handelt, werden die Gewichtungsfaktoren gleichermaßen diskret gewählt. Die Verhältnisse können bei drei Intervallen mit 4,2,1 angenommen werden. Zur Einteilung der Messwerte wird die prozentuale Lage des Dämpfungsfaktors in \si{\dB} im betrachteten Datensatz herangezogen. Ein hoher Dämpfungsfaktor befindet sich in den unteren \SI{40}{\percent}, ein mittlerer befindet sich zwischen \SI{40}{\percent} und \SI{70}{\percent} und ein niedriger wird durch die verbleibenden oberen \SI{30}{\percent} beschrieben.

![Beispiel einer \ac{rssi}-Werte Verteilung einer Messreihe. \label{fig:rssi-verteilung}](../static/rssiwerteverteilung.pdf)

# Versuchsvorbereitung 

Um ein besseres Verständnis über das System und seine Eigenschaften zu erhalten, werden verschiedene Referenzmessungen durchgeführt: Betrachtet werden hierbei die Auswirkungen der Orientierung von Smartphone und Beacons sowie Abweichungen zwischen der verwendeten Hardware auf die Dämpfung des Signals. Mit dieser Erkenntnis können im weiteren Verlauf die Konstanten zur Berechnung der Entfernung auf das verwendete System kalibriert und der Versuchsaufbau, beschrieben in Kapitel \ref{versuchsaufbau}, optimiert werden. 

Zur Ermittlung des Abstands zwischen den einzelnen Objekten wird jeweils die Mitte des Objekts verwendet. Dies hat den Vorteil, dass bei einer Änderung der Orientierung der tatsächliche Abstand gleich bleibt. Das Smartphone wird mit dem Display nach oben auf der Messunterlage platziert und die Beacons mit dem Gehäuseboden auf die Unterlage gelegt.

## Referenzmessung

Die Referenzmessungen bieten einen Einblick in das System. Sie sollen systematische Einflüsse aufzeigen und so die Entwicklung eines optimierten Versuchsaufbaus ermöglichen. Die ersten Messungen werden im Freien durchgeführt, um etwaige Störeinflüsse durch Reflektionen und \ac{wifi}-Signalen zu verringern. Ein Karton dient als ebene Fläche auf einer Wiese. Auf dem Karton werden nicht nur die Messobjekte platziert, sondern auch Markierungen aufgebracht, um die Positionierung und Ausrichtung zu erleichtern. Abbildung \ref{fig:messung-outdoor} zeigt den Versuchsaufbau.

![Versuchsaufbau der Referenzmessung im Außenbereich. \label{fig:messung-outdoor}](../static/outdoor_versuch.jpg){ width=80% }

Soweit nicht anders beschrieben beträgt der Abstand für die Referenzmessungen \SI{1}{\meter}. Während einer Messung werden die an der Messung beteiligten Geräte nicht bewegt. Die Messdauer einer Referenzmessung wurde auf eine Minute begrenzt. Die Auswertung wird wie in Abschnitt \ref{auswertung} beschrieben durchgeführt.

### Beacon zu Smartphone

Zunächst wird untersucht, ob die verwendete Hardware fehlerfrei funktioniert und ob es starke Schwankungen in der gemessen Dämpfung zwischen den einzelnen Beacons gibt. Hierzu wird jeder Beacon einzeln, nacheinander zum Smartphone gemessen. Eine Auflistung der Versuche findet sich in Tabelle \ref{tab:versuchsaufbau-1m}. 

| Versuchsname | Beacon 1 | Beacon 2 | Beacon 3 |
| ------------ | -------- | -------- | -------- |
| Dist_5b5b | - | - | 100 |
| Dist_690f | - | 100 | - |
| Dist_9d31 | 100 | - | - |
: Versuchsübersicht - Beacon zu Smartphone-Abstand in \si{\centi\meter}. \label{tab:versuchsaufbau-1m}

Die Messergebnisse in Abbildung \ref{fig:ref-beaconSmartphone} Messung "Outdoor 1" zeigen, dass die Geräte eine ähnliche Sendeleistung aufweisen. Die gemessenen Werte liegen dabei zwischen \SIrange{-71}{-74}{\dB} und sind damit innerhalb der \ac{ble}-Spezifikation von $\pm \SI{6}{\dB}$. Die Messergebnisse einer weiteren Messung zu einem anderen Zeitpunkt, zu sehen in Abbildung \ref{fig:ref-beaconSmartphone} Messung "Outdoor 2", zeigen eine höhere Schwankung und eine allgemeine Verschlechterung der gemessenen \ac{rssi}-Werte auf über \SI{-80}{\dB}. Dabei haben sich die Umgebungsbedingungen von der ersten zur zweiten Messung wie folgt verändert: Der Boden war nasser und die Temperatur wesentlich niedriger. Welcher der Faktoren wie auf das System einwirkt wurde aus Zeitgründen nicht näher untersucht.

![Referenzmessung Beacon zu Smartphone auf \SI{1}{\meter} Entfernung. \label{fig:ref-beaconSmartphone}](../static/BeaconSmartphone.pdf)

Eine weitere Messung, durchgeführt im Innenraum, soll die Einflüsse durch Reflektionen und \ac{wifi}-Signalen verifizieren. In Abbildung \ref{fig:ref-beaconSmartphone} Messung "Indoor" ist zu sehen, dass der absolute Messwert im Innenraum besser ist als im Außenbereich. Er liegt nun im Bereich von \SIrange{-61}{-71}{\dB}. Bei diesen Messungen sind jedoch einige Ausreißer zu sehen, ob diese durch Reflektionen oder anderen Einflüssen entstehen, wurde nicht weiter untersucht.

### Winkeleinfluss

Bei der Messung des Winkeleinfluss soll untersucht werden, wie sich die Lage der einzelnen Geräte zueinander auf den \ac{rssi}-Wert auswirken. An den Messungen sind immer zwei Geräte beteiligt. Ein Gerät ist statisch, wird also zwischen den Messungen nicht verändert, das andere wird nach jeder Messung um einen definierten Winkel rotiert. Der Abstand zwischen den Geräten beträgt immer \SI{1}{\meter}. Eine tabellarische Auflistung der durchgeführten Versuche ist in Tabelle \ref{tab:versuchstabelle-rotation} zu finden.  Die Rotation findet im Uhrzeigersinn statt. Es ergibt sich dabei eine Verteilung der Rotationswinkel zum Empfänger gegen den Uhrzeigersinn, dies wird in Abbildung \ref{fig:puck-rotation} veranschaulicht.


| Versuchsname | Beacon 1 | Beacon 2 | Smartphone | 
| ------------- | -------- | -------- | ---------- | 
| SmartphoneRotation0 | 0 | - | 0 | 
| SmartphoneRotation45 | 0 | - | 45 |
| SmartphoneRotation90 | 0 | - | 90 | 
| SmartphoneRotation135 | 0 | - | 135 | 
| SmartphoneRotation180 | 0 | - | 180 | 
| SmartphoneRotation225 | 0 | - | 225 |
| SmartphoneRotation270 | 0 | - | 270 |
| SmartphoneRotation315 | 0 | - | 315 |
| BeaconRotation0 | 0 | - | 0 |
| BeaconRotation90 | 90 | - | 0 |
| BeaconRotation180 | 180 | - | 0 |
| BeaconRotation270 | 270 | - | 0 |
| BeaconBeaconRotation0 | 0 | 0 | - |
| BeaconBeaconRotation90 | 0 | 90 | - |
| BeaconBeaconRotation180 | 0 | 180 | - |
| BeaconBeaconRotation270 | 0 | 270 | - |
: Versuchsübersicht - Untersuchung des Einfluss verschiedener Rotationswinkel bei \SI{1}{\meter} Entfernung auf den \ac{rssi}-Wert. \label{tab:versuchstabelle-rotation}

![Verteilung der Rotationswinkel am Beispiel des Beacons. \label{fig:puck-rotation}](../static/BeaconRotation.pdf){ width=60% }

#### Smartphone Rotation {-}

Bei den ersten Messungen wird das Smartphone zwischen jeder Messreihe in \SI{45}{\degree} Schritten rotiert und als Referenz die Signalstärke eines Beacon auf \SI{1}{\meter} gemessen. Gerade beim Smartphone ist diese Messung sehr interessant, da die Lage der Bluetooth-Antenne nicht öffentlich dokumentiert ist. Das Smartphone wird hierbei um den Mittelpunkt rotiert. Der Lautsprecher, also das obere Ende des Smartphones, kennzeichnet \SI{0}{\degree}. In Abbildung \ref{fig:ref-smartphoneRotation} ist zu erkennen, dass der gemessene \ac{rssi}-Wert bei \SI{90}{\degree} die größte Dämpfung erfährt. Der mittlere \ac{rssi}-Wert erstreckt sich von \SI{-77}{\dB} bei \SI{225}{\degree} und \SI{315}{\degree} bis \SI{-91}{\dB} bei \SI{90}{\degree}. 

![Referenzmessung bei Smartphone Rotation im Uhrzeigersinn. \label{fig:ref-smartphoneRotation}](../static/SmartphoneRotation.pdf)

Der abgebildete Dämpfungsverlauf über \SI{45}{\degree}, \SI{90}{\degree} und \SI{135}{\degree} lässt die Annahme zu, das sich die Antenne über die rechte Smartphoneseite erstreckt. Beim Einsatz der Formel \ref{eq:beacondistance} mit den Konstanten für das Nexus 4 und einer $txPower$ von \SI{-81}{\dB}, ermittelt aus dem mittleren \ac{rssi}-Wert der Messreihe, äußert sich die \ac{rssi}-Differenz zwischen \SI{225}{\degree} und \SI{90}{\degree} in einer Entfernungsdifferenz von rund \SI{1,6}{\meter}.

#### Beacon Rotation {-}

Für die nächste Messung wird ein Beacon in \SI{90}{\degree} Schritten im Uhrzeigersinn um seinen Mittelpunkt rotiert. Der Versuchsaufbau ist in Abbildung \ref{fig:pucksmartphone-rotation} dargestellt. Der Chip des Beacons kennzeichnet \SI{0}{\degree} und das Smartphone zeigt mit dem Hörer zum Beacon. Bei den Messungen ist die Schwankung des mittleren \ac{rssi}-Werts, von \SI{-64}{\dB} bei \SI{180}{\degree} bis \SI{-68}{\dB} bei \SI{270}{\degree}, als gering einzustufen. Wie Abbildung \ref{fig:ref-beaconrotation} Messung "Beacon zu Smartphone" zeigt, ist die Streuung der Messwerte bei \SI{90}{\degree} und \SI{180}{\degree} am größten.

![Versuchsaufbau Rotation Beacon zu Smartphone. \label{fig:pucksmartphone-rotation}](../static/SmartphoneBeaconRotation.pdf)

\newpage

![Referenzmessung bei der Rotation des Beacons im Uhrzeigersinn. \label{fig:ref-beaconrotation}](../static/BeaconRotationAuswertung.pdf)

Als letzte Messung wird die Rotation eines Beacons in Referenz zu einem zweiten Beacon, der während der Messung nicht bewegt wird und somit statisch ist, untersucht. Hierbei lässt sich sowohl eine Aussage über die Dämpfung bei der Abstrahlung des Signals als auch die Dämpfung beim Empfang eines Signals treffen. Der statische Beacon ist bei der Messung mit \SI{0}{\degree}, wie in Abbildung \ref{fig:puck-rotation} gezeigt, zum rotierenden Beacon ausgerichtet. Der \ac{rssi}-Wert, der am statischen Beacon gemessen wird, zeigt die Dämpfung des ausgehenden Signals beim rotierenden Beacon und ist in Abbildung \ref{fig:ref-beaconrotation} in Messung "statischer Beacon eingehend" zu sehen. Die Messung "rotierender Beacon eingehend" zeigt im Gegenzug das am rotierenden Beacon eingehende Signal, welches vom statischen Beacon ausgesendet wird.

## Durchführung der Kalibrierung

Die Konstanten $A$, $B$, und $C$ aus Kapitel \ref{entfernungsmessung-mit-der-signalstärke} Formel \ref{eq:beacondistance} werden durch Kalibrierungsmessungen nach der Anleitung der Android Beacon Library [@RadiusNetworks_2021] ermittelt. Die Kalibrierung bezieht sich in dieser Anleitung auf ein anderes System und wird mithilfe eines iPhones als Referenzgerät durchgeführt. Außerdem werden in der Anleitung Messreihen von \SI{0.25}{\meter} bis \SI{40}{\meter} angefertigt. Da der maximale Abstand in dieser Arbeit bei \SI{1.5}{\meter} liegt, soll die Kalibrierung auf den Bereich von \SI{0.25}{\meter} bis \SI{2}{\meter} in Schritten zu je \SI{0.25}{\meter} durchgeführt werden. Die $scPower$ wird im späteren Versuch durch die benachbarten Beacons erfasst, daher kommt für die Referenzmessung anstelle des iPhones ein zweiter Beacon zum Einsatz. 

Wie aus den Messungen in Abschnitt \ref{beacon-smartphone} hervor geht, weichen die \ac{rssi}-Werte bei feuchter Witterung im Außenbereich stark von denen im Innenbereich ab. Zum Zeitpunkt der Messungen war eine Trockenperiode nicht absehbar, aus diesem Grund wird die Kalibrierung im Innenraum durchgeführt. Um den Einfluss von Störfaktoren wie Reflektionen zu vermindern, wird die Messung möglichst weit entfernt von Wänden und anderen Objekten durchgeführt. Zusätzlich werden alle beweglichen Funkquellen aus der näheren Umgebung des Messbereichs geräumt. Um den Einfluss zufälliger Fehler durch die nicht optimalen Umgebungsbedingungen weiter zu reduzieren, wird die Messdauer von den in der Anleitung verwendeten \SI{20}{\second} auf \SI{1}{\minute} angehoben.

Mit der aus Formel \ref{eq:beacondistance} entstammenden Formel \ref{eq:regress} wird nun eine Regression auf die Messdaten der Kalibrierung durchgeführt. Dabei werden Parameter für die Konstanten $A$ und $B$ ermittelt, durch die die Berechnungen der Messdaten möglichst gut mit der Distanz $d$ übereinstimmen.	

\begin{equation}\label{eq:regress}
\begin{aligned}
d = A \cdot \left( \cfrac{P_{R_{x}}}{txPower} \right)^{B}
\end{aligned}
\end{equation}

Die Konstante $C$ beschreibt den Korrekturfaktor für \SI{1}{\meter} Entfernung. Hierzu werden die Konstanten $A = 1,7358$ und $B = 7,5924$ aus der Regression in die Formel \ref{eq:korrektur} eingesetzt und die Messwerte für die Referenzentfernung $d = \SI{1}{\meter}$ eingesetzt. Daraus ergibt sich die Konstante $C$ zu $-0,1688$.

\begin{equation}\label{eq:korrektur}
\begin{aligned}
C = d - A \cdot \left( \cfrac{P_{R_{x}}}{txPower} \right)^{B}
\end{aligned}
\end{equation}

In Abbildung \ref{fig:calibration} ist der durchschnittliche Fehler auf die einzelnen Entfernungen aufgetragen. Verglichen wird der Fehler unter Verwendung der Kalibrierungsfaktoren zur Verwendung der Standardwerte der Android Beacon Library. Die $txPower$, welche sich aus der Kalibrierung ergibt und für die weiteren Messungen eingesetzt wird, beträgt \SI{-67}{\dB}. Es ist zu erkennen, dass die Fehlerquote nach Kalibrierung, ab \SI{0.75}{\meter} niedriger ist als mit den Standardwerten.

![Gegenüberstellung der Kalibrierungsfaktoren zu den Standardwerten (Nexus 4) in der Android Beacon Library. \label{fig:calibration}](../static/calibrationValidation.pdf)

# Versuchsaufbau

In diesem Kapitel wird der Versuchsaufbau für die Umsetzung einer Lokalisierungslösung beschrieben. Als Grundlage dienen dabei die zuvor ermittelten Daten aus der Referenzmessung sowie die Arbeit von Cho et al. [@Cho_2015a]. Ein besonderer Fokus liegt auf einen einfachen Aufbau, der leicht nachzubilden ist und dabei ein hohes Maß an Genauigkeit ermöglicht.

## Anordnung der Beacons

Die Bluetooth-Beacons werden in einem gleichseitigen Dreieck mit einer Seitenlänge von \SI{1}{\meter} auf einer ebenen Fläche angeordnet (vgl. Abb. \ref{fig:versuchsaufbau}). Hierdurch empfängt jeder Beacon von seinen Nachbarn den \ac{rssi}-Wert auf \SI{1}{\meter} Entfernung und kann somit die $scPower$ für die spätere Entfernungsermittlung an das Smartphone übertragen. Die Ausrichtung der Beacons erfolgt mit den in Abbildung \ref{fig:puck-rotation} gekennzeichneten \SI{180}{\degree} zum Zentrum des Dreiecks. Dieser Versuchsaufbau ermöglicht es, das System um zusätzliche Beacons zu erweitern. Hierdurch ließe sich beispielsweise ein Tetraeder mit 6 gleichlangen Kanten aufbauen, wodurch die Messung auf die 3. Dimension erweitert werden kann.

![Versuchsaufbau mit dem Smartphone an Messpunkt ``A``. \label{fig:versuchsaufbau}](../static/Versuchsaufbau.jpg)

## Messpunkte

Der Versuchsaufbau wird, wie in Abbildung \ref{fig:zones} dargestellt, in drei Zonen eingeteilt. Die ersten beiden Zonen ergeben sich aus der Geometrie des Versuchsaufbaus. Zone 1 hat einen Radius von \SI{0.289}{\meter} und wird durch das gleichseitige Dreieck begrenzt. In dieser Zone ist kein Beacon weiter als \SI{0.866}{\meter} vom Smartphone entfernt. Zone 2 misst einen Radius von \SI{0.577}{\meter} und schließt das Dreieck ein. Die maximale Distanz zu einem Beacon in Zone 2 beträgt \SI{1.154}{\meter}. Bei Zone 3 liegt der am weitesten entfernte Punkt \SI{1.5}{\meter} von einem Beacon entfernt. Dieser wurde gewählt, da der Fehler bei der Ermittlung der Entfernung bis zu einem Abstand von \SI{1.5}{\meter} laut Cho et al. [@Cho_2015a] unter \SI{10}{\percent} liegt. Es ergibt sich dabei ein Radius von \SI{0,932}{\meter} um das Zentrum.

![Aufteilung des Versuchsaufbaus in Zonen und Messpunkte. \label{fig:zones}](../static/Zonen_und_Messpunkte.pdf){ width=60% }

In Tabelle \ref{tab:messpunkte} sind die einzelnen Messpunkte und Abstände zu den Beacons aufgezeigt. Messpunkt A befindet sich im Mittelpunkt, Messpunkt C und D jeweils am äußeren Rand von Zone 2 und Zone 3. Um möglichst viele verschiedene Entfernungen zu den Beacons untersuchen zu können, ist der Messpunkt C nicht mittig zwischen zwei Beacons. Eine besondere Rolle spielt Messpunkt B. Dieser befindet sich auf einer Kante des Dreiecks und liegt somit genau zwischen zwei Beacons. Er wurde gewählt, um den Einfluss des Smartphones auf die Funkstrecke der Beacons untersuchen zu können.

\begin{longtable}{llll}
\caption{Messpunkte und deren Referenzentfernung zu den Beacons.
\label{tab:messpunkte}}\tabularnewline
\toprule
          & \multicolumn{3}{l}{Entfernung in cm} \\
          Messpunkt & 5b5b        & 690f       & 9d31      \\
\midrule
\endfirsthead
%
\endhead
%
A         & 57,7        & 57,7       & 57,7      \\
B         & 86,7        & 50         & 50        \\
C         & 74,3      & 39         & 113,2       \\
D         & 77,5         & 150         & 85        \\
\end{longtable}

Um eine konstante Messung zu gewährleisten, werden die Beacons mittig auf den Referenzpunkt in gleicher Orientierung positioniert. Auch das Smartphone wird jeweils mittig auf den eingezeichneten Messpunkten platziert. Tabelle \ref{tab:messpunkte} zeigt die im Versuch gemessenen Abstände vom Smartphone zu den einzelnen Beacons. Durch die mittige Positionierung wird ein gleichbleibender Abstand garantiert, auch wenn das Smartphone rotiert wird. Die Referenzentfernung wird somit jeweils von der Mitte der Beacons zur Mitte des Smartphones ermittelt. Um die winkelabhängige Dämpfung (beschrieben in Abschnitt \ref{winkeleinfluss}) zu kompensieren, werden zwei Messreihen pro Messpunkt durchgeführt. Dabei wird das Smartphone zwischen den beiden Messreihen einmal um \SI{180}{\degree} rotiert. Die Spitze des Dreiecks, gekennzeichnet durch den Beacon ``690f``, kennzeichnet dabei die Orientierung \SI{0}{\degree}. 

# Ergebnisse

Zunächst soll der Einfluss der Kalibrierung auf die Entfernungsberechnung betrachtet werden. Die Ermittlung der Entfernung findet mit Formel \ref{eq:beacondistance} statt. Gegenübergestellt werden die Konstanten aus der Android Beacon Library für das Nexus 4 ($A = 0,89976$, $B = 7,7095$, $C = 0,111$) sowie die Konstanten aus der Kalibrierung ($A = 1,7358$, $B = 7,5924$, $C = -0,1688$) (siehe Abschnitt \ref{durchfuxfchrung-der-kalibrierung}). Dabei wird der relative Fehler über die gemessenen Entfernungen betrachtet. Abbildung \ref{fig:erg-kalibrierung} zeigt das Verhältnis vom durchschnittlichen relativen Fehler gegenüber den verschiedenen Referenzentfernungen. Die Verbindungslinien zwischen den Messpunkten dienen der besseren Visualisierung und stellen keine Interpolation der Zwischenwerte da. Die roten Linien kennzeichnen den Einsatz der $txPower$, die blauen Linien die der $scPower$. Dabei steht die durchgezogene Linie für die Verwendung der Nexus 4 Konstanten und die gestrichelte Linie für den Einsatz der kalibrierten Konstanten.

![Einfluss der Kalibrierung auf die Bestimmung der Entfernung. Die Messpunkte sind nur zur besseren visuellen Darstellung mit Linien verbunden. \label{fig:erg-kalibrierung}](../static/DistanceErrorKalibration.pdf)

Zu erkennen ist, dass der relative Fehler durch den Einsatz der kalibrierten Konstanten zunimmt. Im Mittel steigt der Fehler über die gemessenen Entfernungen unter Einsatz der $txPower$ von \SI{102,03}{\percent} für die Nexus 4 Konstanten auf \SI{183,47}{\percent} bei den kalibrierten Konstanten. Unter Verwendung der $scPower$ liegt der mittlere Fehler bei \SI{63,97}{\percent} für die Nexus 4 Konstanten und \SI{108,13}{\percent} bei den kalibrierten Konstanten. Der Fehler ist für alle vier betrachteten Methoden bei \SI{0.577}{\meter} am größten. 

Die angewandte Methode zur Kalibrierung hat somit einen negativen Einfluss auf die Genauigkeit der Entfernungsberechnung. Ein Grund hierfür kann die Beschränkung des Messbereichs zur Kalibrierung auf \SI{2}{\meter} sein. Durch die Anpassung des Kalibrierungsbereichs wird das System allgemein anfälliger für Schwankungen in den gemessenen Dämpfungswerten. Dies lässt sich anhand der Referenzmessung aus Abschnitt \ref{winkeleinfluss} Smartphone Rotation zeigen. Hierbei ändert sich der gemessene \ac{rssi}-Wert bei gleicher Entfernung zum Beacon je nach Einfallswinkel. Tabelle \ref{tab:einfallswinkeleinfluss} stellt den relativen Fehler bei der Ermittlung der Distanz unter verschiedenen Einfallswinkeln dar. Es ist zu erkennen, dass Änderungen des \ac{rssi}-Werts bei den kalibrierten Konstanten zu einer stärkeren Abweichung führen als bei den Nexus 4 Konstanten. Die Differenz der relativen Fehler nimmt mit steigendem \ac{rssi}-Wert zu, was für eine höhere Empfindlichkeit auf Änderungen spricht. Aus diesem Grund werden im weiteren Verlauf die Auswertungen mittels Nexus 4 Konstanten vorgenommen.

\begin{longtable}{lllll}
\caption{Vergleich zwischen den Nexus 4 Konstanten und den Konstanten aus der Kalibrierung anhand der Referenzmessung des Einfallswinkels aus Abschnitt \ref{winkeleinfluss} Smartphone Rotation.}
\label{tab:einfallswinkeleinfluss}\\
\toprule
                  &                  & \multicolumn{2}{l}{Relativer Fehler in \si{\percent}} &                    \\
                  Rotationswinkel   & RSSI in \si{\dB} &     \begin{tabular}[c]{@{}l@{}}Nexus 4 \\ Konstanten\end{tabular}     &     \begin{tabular}[c]{@{}l@{}}Kalibrierungs \\ Konstanten\end{tabular}     &     \begin{tabular}[c]{@{}l@{}}Absolute \\ Differenz\end{tabular} \\
\midrule
\endfirsthead
%
\endhead
%
\cline{1-5}
\endfoot
%
\endlastfoot
%
\SI{0}{\degree}   & -78,82           & 225.86                 & 415,53                       & 189,67             \\
\SI{45}{\degree}  & -84,55           & 451,95                 & 790,46                       & 338,51             \\
\SI{90}{\degree}  & -91,11           & 873,00                 & 1482,77                      & 609,77             \\
\SI{135}{\degree} & -82,06           & 340,78                 & 606,49                       & 265,71             \\
\SI{180}{\degree} & -79,67           & 253,26                 & 461,15                       & 207,89             \\
\SI{225}{\degree} & -77,30           & 182,09                 & 342,53                       & 160,44             \\
\SI{270}{\degree} & -79,21           & 238,11                 & 435,94                       & 197,83             \\
\SI{315}{\degree} & -77,17           & 178,49                 & 336,52                       & 158,03             \\ \cline{1-5} 
\end{longtable}

Als Nächstes wird die Auswirkung der $scPower$ anstelle der $txPower$ bei der Entfernungsberechnung untersucht: Aus Abbildung \ref{fig:erg-kalibrierung} geht hervor, dass die $scPower$ einen positiven Einfluss auf die Entfernungsermittlung hat. Dabei liegt der durchschnittliche Fehler beim Einsatz der $scPower$ über die verschiedenen Referenzentfernungen um \SI{35,85}{\percent} niedriger als bei der Verwendung der $txPower$. Abbildung \ref{fig:distScTx} veranschaulicht die Verteilung der errechneten Entfernungen mittels $txPower$ und $scPower$. Es ist zu erkennen, dass die ermittelten Entfernungswerte der $scPower$ dichter beieinander liegen und weniger stark streuen.

![Gegenüberstellung der Entfernungsermittlung auf verschiedenen Distanzen von $scPower$ und $txPower$. \label{fig:distScTx}](../static/DeviceDistanceScTxPower.pdf)

Durch die Filterung der \ac{rssi}-Werte sollen Schwankungen in den Messwerten ausgeglichen und die Entfernungsberechnung verbessert werden. Abbildung \ref{fig:err-filter} bestätigt eine positive Auswirkung durch den Einsatz von Filtern. Dabei werden die relativen Fehler zu den Referenzentfernungen für die ungefilterten RSSI Werte (rote), dem gleitenden Mittelwert (gelbe) und dem gewichteten Mittelwert (blaue) gegenübergestellt. Der farbige Schatten zeigt die Standardabweichung an.

![Einfluss der verschiedenen Filtermethoden auf die Entfernungsberechnung mittels $scPower$ \label{fig:err-filter}](../static/DistanceErrorFilter.pdf)

Unter Verwendung der $scPower$ lag der durchschnittliche Fehler der Rohdaten bei \SI{75.68}{\percent}, der des gleitenden Mittelwerts bei \SI{73,99}{\percent} und der des gewichteten Mittelwerts bei \SI{70.07}{\percent}. Damit ist die Auswirkung des gewichteten Mittelwerts mit einer Verbesserung um \SI{7.42}{\percent} am größten.

Im Weiteren soll überprüft werden, ob sich die zuvor gewonnenen Erkenntnisse auch auf die Lokalisierung übertragen lassen. Da die Messung des \ac{rssi}-Wertes am Smartphone vom Einstrahlwinkel beeinflusst wird (siehe Abschnitt \ref{winkeleinfluss}), wurden die Messungen in zwei Orientierungen durchgeführt, dadurch soll der winkelabhängige Einfluss minimiert werden. In Abbildung \ref{fig:orientierung} ist zu erkennen, dass der Lokalisierungsfehler je nach Orientierungen abhängig vom Messpunkt ist. \SI{180}{\degree} (gelb) liefert bei den Messpunkten A und B einen geringeren Fehler gegenüber \SI{0}{\degree} (blau), welcher bei den Messpunkten C und D einen geringeren Fehler aufweist. In rot ist die Mittlung beider Orientierungen dargestellt, welche für die weitere Betrachtung herangezogen wird.

![Auswirkung der Orientierung des Smartphones auf die verschiedenen Messpunkte \label{fig:orientierung}](../static/Loc0180.pdf)

Abbildung \ref{fig:figerr} stellt den Lokalisierungsfehler an den einzelnen Versuchspositionen da (siehe Kapitel \ref{versuchsaufbau}). Im linken Diagramm wird die $scPower$ (gelbe Linie) gegenüber der $txPower$ (rote Linie) betrachtet. Dabei ist zu erkennen, dass die $scPower$ auch bei der Lokalisierung einen geringeren Fehler aufweist. An Position A, welche im Zentrum des Dreiecks liegt, ist die Abweichung am  größten. Dort besteht eine Differenz von \SI{1216,93}{\percent} zwischen der $txPower$ und $scPower$. Im Durchschnitt bietet die $scPower$ eine Verbesserung der Lokalisierung um \SI{61.35}{\percent} gegenüber der $txPower$.

![Betrachtung des Lokalsierungsfehlers: Vergleich zwischen $txPower$ und $scPower$ (links); Vergleich der Filter unter Verwendung der $scPower$ (rechts). \label{fig:figerr}](../static/LocErrorTests.pdf)

Im rechten Diagramm von Abbildung \ref{fig:figerr} sind die Rohdaten den verschiedenen Filtern unter Verwendung der $scPower$ gegenübergestellt. Dabei zeigt sich, dass der gewichtete Mittelwert mit durchschnittlich \SI{189,52}{\percent} (blaue Linie) auch bei der Lokalisierung den geringsten Fehler gegenüber den Rohdaten \SI{226.07}{\percent} (rote Linie) und dem gleitenden Mittelwert \SI{204.32}{\percent} (gelbe Linie) aufweist. Somit bietet dieser eine Verbesserung von \SI{16.17}{\percent} gegenüber den Rohdaten.

Unter Anwendung dieser Erkenntnisse wird in Abbildung \ref{fig:punktwolken} die Positionsbestimmung grafisch betrachtet. Dargestellt sind die, mittels $scPower$ und gleitendem Mittelwertfilter errechneten Punkte (gelb). Die Positionen der Beacons sind blau markiert und der rote Punkt stellt den Mittelpunkt der Punktwolke da. In grün ist der reale Punkt, ermittelt aus den Referenzentfernungen eingezeichnet. Der ``locErr`` gibt den Fehler des roten Punkts zum Referenzpunkt in Prozent an.

![Darstellung der ermittelten Positionen (gelb) und der realen Position (grün) sowie des Mittelwerts der ermittelten Positionen (rot). \label{fig:punktwolken}](../static/position_auswertung.pdf){ width=90% }

Es zeigt sich, dass die Punktwolke sehr stark um den Mittelpunkt streut. Der Mittelpunkt weißt dabei einen Lokalisierungsfehler von \SIrange{40.22}{143}{\percent} auf. Die Lokalisierung ist hierbei weder Präzise, noch weist sie eine hohe Richtigkeit auf. Die Verteilung der Punktwolke an Testposition C weicht dabei von den der anderen Position ab. Bei näherer Betrachtung stellt sich heraus, dass die ermittelte Entfernung zum Beacon ``5b5b`` unten rechts,  mit durchschnittlich \SI{0.33}{\meter} um \SI{0.42}{\meter} unterschätzt wird. Hinzu kommt die geringe Entfernung zum Beacon ``690f`` von \SI{0.39}{\meter}, hierdurch gibt es zwischen den Beacons ``5b5b`` und ``690f`` keine Überschneidung. 

# Diskussion

Die Umsetzung einer Lokalisierungslösung mit einer Auflösung im Zentimeterbereich ist mit dem entwickelten Konzept nicht gelungen. Auch durch den Einsatz der $scPower$ und dem gleitenden Mittelwert, welche zusammen den durchschnittlich geringsten Fehler aufweisen, weichen die ermittelten Positionen im Durchschnitt \SI{129}{\centi\meter} von der realen Position ab. Im Folgenden sollen daher die Ergebnisse diskutiert und auf Einzelaspekte näher eingegangen werden. 

Die Arbeit belegt, dass der Einsatz der $scPower$ einen positiven Einfluss auf die Entfernungsermittlung hat. Es wird gezeigt, dass dieser positive Einfluss auch auf die Lokalisierung übertragbar ist. Eine Genauigkeit von unter \SI{10}{\percent} wie sie Cho at el. [@Cho_2015a] erreicht haben, konnte mit der hier verwendeten Hardware nicht reproduziert werden. Dabei konnten die Beacons aus der Arbeit von Cho at el. mangels Programmierschnittstelle nicht eingesetzt werden. Bei den Beacons fehlt es generell an einer Auswahl von alternativer Hardware, welche auch programmierbar ist. 

Des Weiteren wird gezeigt, dass der Einsatz der Filtermethoden nicht nur auf die Entfernungsmessung mittels $txPower$ einen positiven Einfluss hat, sondern auch die Messungen der $scPower$ verbessert. Der gewichtete Mittelwert-Filter bietet hierbei die besten Ergebnisse für das eingesetzte System. Der Einsatz spezialisierter Filter wie beispielsweise dem Kalmann-Filter bietet weiteres Optimierungspotential. Dies konnte aus Zeitgründen in dieser Arbeit jedoch nicht untersucht werden.

Entscheidend für gute Messergebnisse ist auch die Hardware. Der \ac{rssi}-Wert schwankt beim eingesetzten Smartphone je nach Einfallswinkel sehr stark. Daher wird die Messung im Versuchsaufbau in zwei Orientierungen durchgeführt, um diese Winkelabhängigkeit auszugleichen. Es ist zu vermuten, dass auch andere Geräte eine solche Abhängigkeit aufweisen. Durch die Kombination dieses Verfahrens mit zusätzlichen Sensoren wie beispielsweise dem Magnetometer oder Gyroskop, zur Erkennung der Ausrichtung des Smartphones, könnte dieser Einfluss kompensiert werden. Da die Beacons jedoch eine geringe winkelabhängige Dämpfung aufweisen, könnte der Einsatz eines vierten Beacons anstelle des Smartphones Verbesserungspotential bieten. Durch das homogene System sollte die $scPower$ einen noch größeren Einfluss auf die Genauigkeit aufweisen.

Die auf das System angepasste Kalibrierung ist bei den auftretenden Schwankungen des gemessenen \ac{rssi}-Wertes zu fehleranfällig. Den größten Einfluss auf diese Fehleranfälligkeit hat vermutlich der auf \SI{2}{\meter} reduzierte Messbereich, auf dem die Kalibrierung durchgeführt wird. Durch die Ausweitung dieses Bereichs auf \SI{40}{\meter}, die in der Android Beacon Library [@RadiusNetworks_2021] beschrieben sind, könnte die Fehleranfälligkeit reduziert werden. Für die Arbeit stand jedoch kein Raum mit ausreichender Größe zur Verfügung. Die unbeständige Wetterlage und der, aus den Messungen hervorgehende, negativen Einfluss von Feuchtigkeit ließen keine Kalibrierungsmessungen im Freien zu.

Abschließend bleibt zu bewerten, ob der Einsatz von Bluetooth die richtige Wahl zur Bestimmung der Position im Zentimeterbereich ist. Wie sich gezeigt hat, ist der Dämpfungsfaktor ein von vielen Einflussfaktoren abhängender Wert. Für eine zuverlässige Messung müssen sehr viele Umgebungsvariablen berücksichtigt werden. Dies ist vor allem in den Referenzmessungen zu erkennen, bei denen sich der Einfluss von feuchter Witterung in sehr viel schlechteren Messwerten äußerte. Diese Faktoren sind selbst unter idealen Bedingungen nur schwer zu kontrollieren. Durch den Einsatz der $scPower$, welche den gleichen Einflussfaktoren ausgeliefert ist, lässt sich die Messung zwar verbessern, jedoch bleibt auch diese weit hinter den Erwartungen zurück. Ein andere Ansatz bietet der neue Bluetooth Standard 5.2, welcher die Messung des \acl{aoa}, also des Einfallswinkels, ermöglicht. Der Standard muss hierbei von Sender und Empfänger unterstützt werden, damit sollen jedoch Messungen im Zentimeterbereich ermöglicht werden. Zum Zeitpunkt der Arbeit sind Geräte mit diesem Standard noch sehr selten. Nur die aktuellsten Smartphones setzen Bluetooth-Chips mit diesem Standard ein, Bluetooth-Beacons konnten am Markt keine gefunden werden.

# Zusammenfassung 

In dieser Arbeit wurde ein neuartiges Lokalisierungskonzept entwickelt und evaluiert, wodurch sich Messungen im Zentimeterbereich durchführen lassen. Dieses Konzept dient als Vorlage zur Erweiterung der Anwendung phyphox&reg;, um Experimente mit dem Smartphone auf Basis der Position durchführen zu können.

Zunächst wurden die Grundlagen und der Stand der Technik dargelegt und durch eine systematische Bewertung eingegrenzt. Hierzu wurde die Zielsetzung herangezogen und die Methoden hinsichtlich ihrer Auswirkungen zur Erreichung des Ziels bewertet. Im Weiteren wurde auf die verwendete Hardware und die Umsetzung der einzelnen Komponenten eingegangen und einzelne Aspekte herausgestellt.

Es folgte eine experimentelle Untersuchung der einzelnen Komponenten, um die spezifischen Eigenschaften der eingesetzten Geräte zu charakterisieren. Durch Anwendung der Erkenntnisse aus diesen Experimenten, den Grundlagen und dem Stand der Technik wurde dann ein Konzept für einen Versuchsaufbau entwickelt.

Abschließend wurde der entwickelte Versuchsaufbau experimentellen Tests unterzogen. Hierfür wurden Messreihen mit verschiedenen Positionen angefertigt und ausgewertet. Des Weiteren wurden verschiedene Methoden und Filter auf die Entfernungsmessung und Lokalisierung angewandt und hinsichtlich ihrer Auswirkungen auf die Messgenauigkeit bewertet.

Es konnte ein Konzept entwickelt werden, durch das` eine Positionsbestimmung möglich ist. Es wurde gezeigt, dass die angewandten Filter und das selbst korrigierende System zur Ermittlung der Entfernung, sowie zur Lokalisierung zu einer Verbesserung der Ergebnisse führen. Die Genauigkeit von wenigen Zentimeter konnte jedoch nicht erreicht werden. Auch die Ergebnisse aus der zugrundeliegenden Literatur ließen sich mit der eingesetzten Hardware nicht reproduzieren.

## Fazit

Mit der eingesetzten Technik und den zugrundeliegenden Methoden kann eine Verbesserung der Entfernungsmessung und Lokalisierung erreicht werden. Durch den Einsatz von Filtern lässt sich die Messgenauigkeit für das eingesetzte Messverfahren erhöhen. Die Verbesserung der Genauigkeit auf wenige Zentimeter Abweichung kann nicht erreicht werden. Die in der Literatur beschriebenen \SI{10}{\percent} Abweichung in einem Messradius von \SI{1.5}{\meter} um einen Beacon konnten nicht reproduziert werden. Durch die angepasste Kalibrierung wurden die ermittelten Entfernungswerte stärker durch Schwankungen der gemessenen Dämpfungsfaktoren beeinflusst. Ein stabileres Ergebnis liefern die nicht auf das System optimierten Standardwerte für das Nexus 4. Mit einer Abweichung von durchschnittlich \SI{204.32}{\percent} und einer sich daraus ergebenen Differenz von \SI{129}{\centi\meter} ist das eingesetzte Verfahren nicht für Tischexperimente geeignet.

## Ausblick 

Durch den Einsatz weiterer Sensoren ließe sich das Verfahren weiter optimieren. Sowohl die Ausrichtung des Smartphones als auch Informationen zur Beschleunigung und Bewegungsrichtung könnten bei den Messungen berücksichtigt und zur Filterung eingesetzt werden. Auch der Einsatz optimierter Filter wie beispielsweise einen Kalmann-Filter könnte die Messgenauigkeit erhöhen. 

Der Einfluss von Feuchtigkeit und Temperatur auf die Signalstärke sollte näher untersucht werden. Gerade der Einfluss durch die relative Luftfeuchtigkeit könnte Erkentnisse liefern, durch die die Signalstärkeermittlung verbessert werden kann.

Weiter bietet sich die Untersuchung von \ac{ble} 5.2 und der neu integrierten \acl{aoa} Funktion an. Hierdurch kann nicht nur die Entfernungsmessung verbessert, sondern auch die Orientierung innerhalb des Versuchsaufbaus bestimmt werden.